"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QFontMetrics(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qfontmetrics.html

    **Detailed Description**

    QFontMetrics functions calculate the size of characters and strings for a
    given font. There are three ways you can create a QFontMetrics object:

    1. Calling the QFontMetrics constructor with a **QFont**  creates a font
    metrics object for a screen-compatible font, i.e. the font cannot be a
    printer font. If the font is changed later, the font metrics object is
    **not** updated.

    (Note: If you use a printer font the values returned may
    be inaccurate. Printer fonts are not always accessible so the nearest screen
    font is used if a printer font is supplied.)

      2. **QWidget::fontMetrics**
    () returns the font metrics for a widget's font. This is equivalent to
    QFontMetrics(widget->font()). If the widget's font is changed later, the
    font metrics object is **not** updated.
      3. **QPainter::fontMetrics** ()
    returns the font metrics for a painter's current font. If the painter's font
    is changed later, the font metrics object is **not** updated.

    Once created, the object provides functions to access the individual metrics
    of the font, its characters, and for strings rendered in the font.

    There are several functions that operate on the font: **ascent** (),
    **descent** (), **height** (), **leading** () and **lineSpacing** () return
    the basic size properties of the font. The **underlinePos** (),
    **overlinePos** (), **strikeOutPos** () and **lineWidth** () functions,
    return the properties of the line that underlines, overlines or strikes out
    the characters. These functions are all fast.

    There are also some functions that operate on the set of glyphs in the font:
    **minLeftBearing** (), **minRightBearing** () and **maxWidth** (). These are
    by necessity slow, and we recommend avoiding them if possible.

    For each character, you can get its **horizontalAdvance** (),
    **leftBearing** (), and **rightBearing** (), and find out whether it is in
    the font using **inFont** (). You can also treat the character as a string,
    and use the string functions on it.

    The string functions include **horizontalAdvance** (), to return the width
    of a string in pixels (or points, for a printer), **boundingRect** (), to
    return a rectangle large enough to contain the rendered string, and **size**
    (), to return the size of that rectangle.

    Example:

    **QFont**  font("times", 24);
        **QFontMetrics**  fm(font);
        int
    pixelsWide = fm.horizontalAdvance("What's the width of this text?");
        int
    pixelsHigh = fm.height();

    **See also** **QFont** , **QFontInfo** , **QFontDatabase** , and **Character
    Map Example** .
    """

    @typing.overload
    def __init__(self, a0: QFont) -> None:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#QFontMetrics

        **QFontMetrics::QFontMetrics(const QFont & font )**

        Constructs a font metrics object for **font**.

        The font metrics will be compatible with the paintdevice used to create
        **font**.

        The font metrics object holds the information for the font that is
        passed in the constructor at the time it is created, and is not updated
        if the font's attributes are changed later.

        Use QFontMetrics(const **QFont**  &, **QPaintDevice**  *) to get the
        font metrics that are compatible with a certain paint device.
        """
        ...

    @typing.overload
    def __init__(self, font: QFont, pd: QPaintDevice) -> None:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#QFontMetrics-1

        **[since 5.13] QFontMetrics::QFontMetrics(const QFont & font , const
        QPaintDevice * paintdevice )**

        Constructs a font metrics object for **font** and **paintdevice**.

        The font metrics will be compatible with the paintdevice passed. If the
        **paintdevice** is `nullptr`, the metrics will be screen-compatible, ie.
        the metrics you get if you use the font for drawing text on a
        **widgets**  or **pixmaps** , not on a **QPicture**  or **QPrinter** .

        The font metrics object holds the information for the font that is
        passed in the constructor at the time it is created, and is not updated
        if the font's attributes are changed later.

        This function was introduced in Qt 5.13.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QFontMetrics") -> None:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#QFontMetrics-2

        **QFontMetrics::QFontMetrics(const QFontMetrics & fm )**

        Constructs a copy of **fm**.
        """
        ...

    def fontDpi(self) -> float:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#fontDpi

        **[since 5.14] qreal QFontMetrics::fontDpi() const**

        Returns the font DPI.

        This function was introduced in Qt 5.14.
        """
        ...

    def horizontalAdvance(self, a0: str, length: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#horizontalAdvance

        **[since 5.11] int QFontMetrics::horizontalAdvance(const QString & text
        , int len = -1) const**

        Returns the horizontal advance in pixels of the first **len** characters
        of **text**. If **len** is negative (the default), the entire string is
        used.

        This is the distance appropriate for drawing a subsequent character
        after **text**.

        This function was introduced in Qt 5.11.

        **See also** **boundingRect** ().
        """
        ...

    def capHeight(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#capHeight

        **[since 5.8] int QFontMetrics::capHeight() const**

        Returns the cap height of the font.

        The cap height of a font is the height of a capital letter above the
        baseline. It specifically is the height of capital letters that are flat
        - such as H or I - as opposed to round letters such as O, or pointed
        letters like A, both of which may display overshoot.

        This function was introduced in Qt 5.8.

        **See also** **ascent** ().
        """
        ...

    def swap(self, other: "QFontMetrics") -> None:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#swap

        **[since 5.0] void QFontMetrics::swap(QFontMetrics & other )**

        Swaps this font metrics instance with **other**. This function is very
        fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def inFontUcs4(self, character: int) -> bool:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#inFontUcs4

        **bool QFontMetrics::inFontUcs4(uint ucs4 ) const**

        Returns `true` if the character **ucs4** encoded in UCS-4/UTF-32 is a
        valid character in the font; otherwise returns `false`.
        """
        ...

    def tightBoundingRect(self, text: str) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#tightBoundingRect

        **QRect QFontMetrics::tightBoundingRect(const QString & text ) const**

        Returns a tight bounding rectangle around the characters in the string
        specified by **text**. The bounding rectangle always covers at least the
        set of pixels the text would cover if drawn at (0, 0).

        Note that the bounding rectangle may extend to the left of (0, 0), e.g.
        for italicized fonts, and that the width of the returned rectangle might
        be different than what the **horizontalAdvance** () method returns.

        If you want to know the advance width of the string (to lay out a set of
        strings next to each other), use **horizontalAdvance** () instead.

        Newline characters are processed as normal characters, **not** as
        linebreaks.

        **Warning:** Calling this method is very slow on Windows.

        **See also** **horizontalAdvance** (), **height** (), and
        **boundingRect** ().
        """
        ...

    def elidedText(
        self, text: str, mode: QtCore.Qt.TextElideMode, width: int, flags: int = ...
    ) -> str:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#elidedText

        **QString QFontMetrics::elidedText(const QString & text ,
        Qt::TextElideMode mode , int width , int flags = 0) const**

        If the string **text** is wider than **width** , returns an elided
        version of the string (i.e., a string with "..." in it). Otherwise,
        returns the original string.

        The **mode** parameter specifies whether the text is elided on the left
        (e.g., "...tech"), in the middle (e.g., "Tr...ch"), or on the right
        (e.g., "Trol...").

        The **width** is specified in pixels, not characters.

        The **flags** argument is optional and currently only supports
        **Qt::TextShowMnemonic**  as value.

        The elide mark follows the **layoutdirection** . For example, it will be
        on the right side of the text for right-to-left layouts if the **mode**
        is `Qt::ElideLeft`, and on the left side of the text if the **mode** is
        `Qt::ElideRight`.
        """
        ...

    def averageCharWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#averageCharWidth

        **int QFontMetrics::averageCharWidth() const**

        Returns the average width of glyphs in the font.
        """
        ...

    def lineWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#lineWidth

        **int QFontMetrics::lineWidth() const**

        Returns the width of the underline and strikeout lines, adjusted for the
        point size of the font.

        **See also** **underlinePos** (), **overlinePos** (), and
        **strikeOutPos** ().
        """
        ...

    def strikeOutPos(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#strikeOutPos

        **int QFontMetrics::strikeOutPos() const**

        Returns the distance from the base line to where the strikeout line
        should be drawn.

        **See also** **underlinePos** (), **overlinePos** (), and **lineWidth**
        ().
        """
        ...

    def overlinePos(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#overlinePos

        **int QFontMetrics::overlinePos() const**

        Returns the distance from the base line to where an overline should be
        drawn.

        **See also** **underlinePos** (), **strikeOutPos** (), and **lineWidth**
        ().
        """
        ...

    def underlinePos(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#underlinePos

        **int QFontMetrics::underlinePos() const**

        Returns the distance from the base line to where an underscore should be
        drawn.

        **See also** **overlinePos** (), **strikeOutPos** (), and **lineWidth**
        ().
        """
        ...

    def size(
        self,
        flags: int,
        text: str,
        tabStops: int = ...,
        tabArray: typing.Optional[typing.Optional[typing.List[int]]] = ...,
    ) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#size

        **QSize QFontMetrics::size(int flags , const QString & text , int
        tabStops = 0, int * tabArray = nullptr) const**

        Returns the size in pixels of **text**.

        The **flags** argument is the bitwise OR of the following flags:

        * **Qt::TextSingleLine**  ignores newline characters.
          *
        **Qt::TextExpandTabs**  expands tabs (see below)
          *
        **Qt::TextShowMnemonic**  interprets "&x" as **x** ; i.e., underlined.
        * **Qt::TextWordWrap**  breaks the text to fit the rectangle.

        If **Qt::TextExpandTabs**  is set in **flags** , then: if **tabArray**
        is non-null, it specifies a 0-terminated sequence of pixel-positions for
        tabs; otherwise if **tabStops** is non-zero, it is used as the tab
        spacing (in pixels).

        Newline characters are processed as linebreaks.

        Despite the different actual character heights, the heights of the
        bounding rectangles of "Yes" and "yes" are the same.

        **See also** **boundingRect** ().
        """
        ...

    @typing.overload
    def boundingRect(self, text: str) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#boundingRect

        **QRect QFontMetrics::boundingRect(QChar ch ) const**

        Returns the rectangle that is covered by ink if character **ch** were to
        be drawn at the origin of the coordinate system.

        Note that the bounding rectangle may extend to the left of (0, 0) (e.g.,
        for italicized fonts), and that the text output may cover **all** pixels
        in the bounding rectangle. For a space character the rectangle will
        usually be empty.

        Note that the rectangle usually extends both above and below the base
        line.

        **Warning:** The width of the returned rectangle is not the advance
        width of the character. Use boundingRect(const **QString**  &) or
        **horizontalAdvance** () instead.

        **See also** **horizontalAdvance** ().
        """
        ...

    @typing.overload
    def boundingRect(
        self,
        rect: QtCore.QRect,
        flags: int,
        text: str,
        tabStops: int = ...,
        tabArray: typing.Optional[typing.Optional[typing.List[int]]] = ...,
    ) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#boundingRect-1

        **QRect QFontMetrics::boundingRect(const QString & text ) const**

        Returns the bounding rectangle of the characters in the string specified
        by **text**. The bounding rectangle always covers at least the set of
        pixels the text would cover if drawn at (0, 0).

        Note that the bounding rectangle may extend to the left of (0, 0), e.g.
        for italicized fonts, and that the width of the returned rectangle might
        be different than what the **horizontalAdvance** () method returns.

        If you want to know the advance width of the string (to lay out a set of
        strings next to each other), use **horizontalAdvance** () instead.

        Newline characters are processed as normal characters, **not** as
        linebreaks.

        The height of the bounding rectangle is at least as large as the value
        returned by **height** ().

        **See also** **horizontalAdvance** (), **height** (),
        **QPainter::boundingRect** (), and **tightBoundingRect** ().
        """
        ...

    @typing.overload
    def boundingRect(
        self,
        x: int,
        y: int,
        width: int,
        height: int,
        flags: int,
        text: str,
        tabStops: int = ...,
        tabArray: typing.Optional[typing.Optional[typing.List[int]]] = ...,
    ) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#boundingRect-2

        **QRect QFontMetrics::boundingRect(const QRect & rect , int flags ,
        const QString & text , int tabStops = 0, int * tabArray = nullptr)
        const**

        This is an overloaded function.

        Returns the bounding rectangle of the characters in the string specified
        by **text** , which is the set of pixels the text would cover if drawn
        at (0, 0). The drawing, and hence the bounding rectangle, is constrained
        to the rectangle **rect**.

        The **flags** argument is the bitwise OR of the following flags:

        * **Qt::AlignLeft**  aligns to the left border, except for Arabic and
        Hebrew where it aligns to the right.
          * **Qt::AlignRight**  aligns to
        the right border, except for Arabic and Hebrew where it aligns to the
        left.
          * **Qt::AlignJustify**  produces justified text.
          *
        **Qt::AlignHCenter**  aligns horizontally centered.
          * **Qt::AlignTop**
        aligns to the top border.
          * **Qt::AlignBottom**  aligns to the bottom
        border.
          * **Qt::AlignVCenter**  aligns vertically centered
          *
        **Qt::AlignCenter**  (== `Qt::AlignHCenter | Qt::AlignVCenter`)
          *
        **Qt::TextSingleLine**  ignores newline characters in the text.
          *
        **Qt::TextExpandTabs**  expands tabs (see below)
          *
        **Qt::TextShowMnemonic**  interprets "&x" as **x** ; i.e., underlined.
        * **Qt::TextWordWrap**  breaks the text to fit the rectangle.

        **Qt::Horizontal**  alignment defaults to **Qt::AlignLeft**  and
        vertical alignment defaults to **Qt::AlignTop** .

        If several of the horizontal or several of the vertical alignment flags
        are set, the resulting alignment is undefined.

        If **Qt::TextExpandTabs**  is set in **flags** , then: if **tabArray**
        is non-null, it specifies a 0-terminated sequence of pixel-positions for
        tabs; otherwise if **tabStops** is non-zero, it is used as the tab
        spacing (in pixels).

        Note that the bounding rectangle may extend to the left of (0, 0), e.g.
        for italicized fonts, and that the text output may cover **all** pixels
        in the bounding rectangle.

        Newline characters are processed as linebreaks.

        Despite the different actual character heights, the heights of the
        bounding rectangles of "Yes" and "yes" are the same.

        The bounding rectangle returned by this function is somewhat larger than
        that calculated by the simpler boundingRect() function. This function
        uses the **maximum left**  and **right**  font bearings as is necessary
        for multi-line text to align correctly. Also, fontHeight() and
        **lineSpacing** () are used to calculate the height, rather than
        individual character heights.

        **See also** **horizontalAdvance** (), **QPainter::boundingRect** (),
        and **Qt::Alignment** .
        """
        ...

    def boundingRectChar(self, a0: str) -> QtCore.QRect:
        ...

    def rightBearing(self, a0: str) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#rightBearing

        **int QFontMetrics::rightBearing(QChar ch ) const**

        Returns the right bearing of character **ch** in the font.

        The right bearing is the left-ward distance of the right-most pixel of
        the character from the logical origin of a subsequent character. This
        value is negative if the pixels of the character extend to the right of
        the **horizontalAdvance** () of the character.

        See **horizontalAdvance** () for a graphical description of this metric.

        **See also** **leftBearing** (), **minRightBearing** (), and
        **horizontalAdvance** ().
        """
        ...

    def leftBearing(self, a0: str) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#leftBearing

        **int QFontMetrics::leftBearing(QChar ch ) const**

        Returns the left bearing of character **ch** in the font.

        The left bearing is the right-ward distance of the left-most pixel of
        the character from the logical origin of the character. This value is
        negative if the pixels of the character extend to the left of the
        logical origin.

        See **horizontalAdvance** () for a graphical description of this metric.

        **See also** **rightBearing** (), **minLeftBearing** (), and
        **horizontalAdvance** ().
        """
        ...

    def inFont(self, a0: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#inFont

        **bool QFontMetrics::inFont(QChar ch ) const**

        Returns `true` if character **ch** is a valid character in the font;
        otherwise returns `false`.
        """
        ...

    def xHeight(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#xHeight

        **int QFontMetrics::xHeight() const**

        Returns the 'x' height of the font. This is often but not always the
        same as the height of the character 'x'.
        """
        ...

    def maxWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#maxWidth

        **int QFontMetrics::maxWidth() const**

        Returns the width of the widest character in the font.
        """
        ...

    def minRightBearing(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#minRightBearing

        **int QFontMetrics::minRightBearing() const**

        Returns the minimum right bearing of the font.

        This is the smallest **rightBearing** (char) of all characters in the
        font.

        Note that this function can be very slow if the font is large.

        **See also** **minLeftBearing** () and **rightBearing** ().
        """
        ...

    def minLeftBearing(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#minLeftBearing

        **int QFontMetrics::minLeftBearing() const**

        Returns the minimum left bearing of the font.

        This is the smallest **leftBearing** (char) of all characters in the
        font.

        Note that this function can be very slow if the font is large.

        **See also** **minRightBearing** () and **leftBearing** ().
        """
        ...

    def lineSpacing(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#lineSpacing

        **int QFontMetrics::lineSpacing() const**

        Returns the distance from one base line to the next.

        This value is always equal to **leading** ()+**height** ().

        **See also** **height** () and **leading** ().
        """
        ...

    def leading(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#leading

        **int QFontMetrics::leading() const**

        Returns the leading of the font.

        This is the natural inter-line spacing.

        **See also** **height** () and **lineSpacing** ().
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#height

        **int QFontMetrics::height() const**

        Returns the height of the font.

        This is always equal to **ascent** ()+**descent** ().

        **See also** **leading** () and **lineSpacing** ().
        """
        ...

    def descent(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#descent

        **int QFontMetrics::descent() const**

        Returns the descent of the font.

        The descent is the distance from the base line to the lowest point
        characters extend to. In practice, some font designers break this rule,
        e.g. to accommodate a certain character, so it is possible (though rare)
        that this value will be too small.

        **See also** **ascent** ().
        """
        ...

    def ascent(self) -> int:
        """
        https://doc.qt.io/qt-6/qfontmetrics.html#ascent

        **int QFontMetrics::ascent() const**

        Returns the ascent of the font.

        The ascent of a font is the distance from the baseline to the highest
        position characters extend to. In practice, some font designers break
        this rule, e.g. when they put more than one accent on top of a
        character, or to accommodate a certain character, so it is possible
        (though rare) that this value will be too small.

        **See also** **descent** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QSoundEffect(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qsoundeffect.html

    **Detailed Description**

    This class allows you to play uncompressed audio files (typically WAV files)
    in a generally lower latency way, and is suitable for "feedback" type sounds
    in response to user actions (e.g. virtual keyboard sounds, positive or
    negative feedback for popup dialogs, or game sounds). If low latency is not
    important, consider using the **QMediaPlayer**  class instead, since it
    supports a wider variety of media formats and is less resource intensive.

    This example shows how a looping, somewhat quiet sound effect can be played:

    **QSoundEffect**  effect;
        effect.setSource(**QUrl**
    ::fromLocalFile("engine.wav"));
        effect.setLoopCount(**QSoundEffect**
    ::Infinite);
        effect.setVolume(0.25f);
        effect.play();

    Typically the sound effect should be reused, which allows all the parsing
    and preparation to be done ahead of time, and only triggered when necessary.
    This assists with lower latency audio playback.

    MyGame()
            : m_explosion(this)
        {
    m_explosion.setSource(**QUrl** ::fromLocalFile("explosion.wav"));
    m_explosion.setVolume(0.25f);

            // Set up click handling etc.
    connect(clickSource, &**QPushButton** ::clicked, &m_explosion,
    &**QSoundEffect** ::play);
        }
        private:
        **QSoundEffect**
    m_explosion;

    Since QSoundEffect requires slightly more resources to achieve lower latency
    playback, the platform may limit the number of simultaneously playing sound
    effects.
    """

    class Status(enum.Enum):
        Null: QSoundEffect = ...
        Loading: QSoundEffect = ...
        Ready: QSoundEffect = ...
        Error: QSoundEffect = ...

    class Loop(enum.Enum):
        Infinite: QSoundEffect = ...

    @typing.overload
    def __init__(
        self, audioDevice: QAudioDevice, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#QSoundEffect

        **QSoundEffect::QSoundEffect(QObject * parent = nullptr)**

        Creates a QSoundEffect with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#QSoundEffect-1

        **QSoundEffect::QSoundEffect(const QAudioDevice & audioDevice , QObject
        * parent = nullptr)**

        Creates a QSoundEffect with the given **audioDevice** and **parent**.
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#stop

        **[slot] void QSoundEffect::stop()**

        Stop current playback.
        """
        ...

    def play(self) -> None:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#play

        **[slot] void QSoundEffect::play()**

        Start playback of the sound effect, looping the effect for the number of
        times as specified in the loops property.
        """
        ...

    def status(self) -> "QSoundEffect.Status":
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#status

        **QSoundEffect::Status QSoundEffect::status() const**

        Returns the current status of this sound effect.

        **Note:** Getter function for property status.
        """
        ...

    def isPlaying(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#isPlaying

        **bool QSoundEffect::isPlaying() const**

        Returns true if the sound effect is currently playing, or false
        otherwise

        **Note:** Getter function for property **playing** .
        """
        ...

    def isLoaded(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#isLoaded

        **bool QSoundEffect::isLoaded() const**

        Returns whether the sound effect has finished loading the **source** ().
        """
        ...

    def setMuted(self, muted: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#setMuted

        **void QSoundEffect::setMuted(bool muted )**

        Sets whether to mute this sound effect's playback.

        If **muted** is true, playback will be muted (silenced), and otherwise
        playback will occur with the currently specified **volume** ().

        **Note:** Setter function for property **muted** .

        **See also** **isMuted** ().
        """
        ...

    def isMuted(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#isMuted

        **bool QSoundEffect::isMuted() const**

        Returns whether this sound effect is muted

        **Note:** Getter function for property **muted** .
        """
        ...

    def setVolume(self, volume: float) -> None:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#setVolume

        **void QSoundEffect::setVolume(float volume )**

        Sets the sound effect volume to **volume**.

        The volume is scaled linearly from `0.0` (silence) to `1.0` (full
        volume). Values outside this range will be clamped.

        The default volume is `1.0`.

        UI volume controls should usually be scaled non-linearly. For example,
        using a logarithmic scale will produce linear changes in perceived
        loudness, which is what a user would normally expect from a volume
        control. See **QAudio::convertVolume** () for more details.

        **Note:** Setter function for property **volume** .

        **See also** **volume** ().
        """
        ...

    def volume(self) -> float:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#volume

        **float QSoundEffect::volume() const**

        Returns the current volume of this sound effect, from 0.0 (silent) to
        1.0 (maximum volume).

        **Note:** Getter function for property volume.

        **See also** **setVolume** ().
        """
        ...

    def setLoopCount(self, loopCount: int) -> None:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#setLoopCount

        **void QSoundEffect::setLoopCount(int loopCount )**

        Set the total number of times to play this sound effect to
        **loopCount**.

        Setting the loop count to 0 or 1 means the sound effect will be played
        only once; pass `QSoundEffect::Infinite` to repeat indefinitely. The
        loop count can be changed while the sound effect is playing, in which
        case it will update the remaining loops to the new **loopCount**.

        **Note:** Setter function for property **loops** .

        **See also** **loopCount** () and **loopsRemaining** ().
        """
        ...

    def loopsRemaining(self) -> int:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#loopsRemaining-prop

        **[read-only] loopsRemaining : const int**

        This property contains the number of loops remaining before the sound
        effect stops by itself, or **QSoundEffect::Infinite**  if that's what
        has been set in **loops** .

        **Access functions:**

        int **loopsRemaining** () const

        **Notifier signal:**

        void ****loopsRemainingChanged** ** ()
        """
        ...

    def loopCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#loopCount

        **int QSoundEffect::loopCount() const**

        Returns the total number of times that this sound effect will be played
        before stopping.

        See the **loopsRemaining** () method for the number of loops currently
        remaining.

        **Note:** Getter function for property **loops** .

        **See also** **setLoopCount** ().
        """
        ...

    def setSource(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#setSource

        **void QSoundEffect::setSource(const QUrl & url )**

        Set the current URL to play to **url**.

        **Note:** Setter function for property **source** .

        **See also** **source** ().
        """
        ...

    def source(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#source

        **QUrl QSoundEffect::source() const**

        Returns the URL of the current source to play

        **Note:** Getter function for property source.

        **See also** **setSource** ().
        """
        ...

    def setAudioDevice(self, device: QAudioDevice) -> None:
        ...

    def audioDevice(self) -> QAudioDevice:
        ...

    @staticmethod
    def supportedMimeTypes() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#supportedMimeTypes

        **[static] QStringList QSoundEffect::supportedMimeTypes()**

        Returns a list of the supported mime types for this platform.
        """
        ...

    @property
    def audioDeviceChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def loadedChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#loadedChanged

        **[signal] void QSoundEffect::loadedChanged()**

        The `loadedChanged` signal is emitted when the loading state has
        changed.
        """
        ...

    @property
    def loopCountChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#loopCountChanged

        **[signal] void QSoundEffect::loopCountChanged()**

        The `loopCountChanged` signal is emitted when the initial number of
        loops has changed.

        **Note:** Notifier signal for property **loops** .
        """
        ...

    @property
    def loopsRemainingChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#loopsRemainingChanged

        **[signal] void QSoundEffect::loopsRemainingChanged()**

        The `loopsRemainingChanged` signal is emitted when the remaining number
        of loops has changed.

        **Note:** Notifier signal for property **loopsRemaining** .
        """
        ...

    @property
    def mutedChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#mutedChanged

        **[signal] void QSoundEffect::mutedChanged()**

        The `mutedChanged` signal is emitted when the mute state has changed.

        **Note:** Notifier signal for property **muted** .
        """
        ...

    @property
    def playingChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#playingChanged

        **[signal] void QSoundEffect::playingChanged()**

        The `playingChanged` signal is emitted when the playing property has
        changed.

        **Note:** Notifier signal for property **playing** .
        """
        ...

    @property
    def sourceChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#sourceChanged

        **[signal] void QSoundEffect::sourceChanged()**

        The `sourceChanged` signal is emitted when the source has been changed.

        **Note:** Notifier signal for property **source** .
        """
        ...

    @property
    def statusChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#statusChanged

        **[signal] void QSoundEffect::statusChanged()**

        The `statusChanged` signal is emitted when the status property has
        changed.

        **Note:** Notifier signal for property **status** .
        """
        ...

    @property
    def volumeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsoundeffect.html#volumeChanged

        **[signal] void QSoundEffect::volumeChanged()**

        The `volumeChanged` signal is emitted when the volume has changed.

        **Note:** Notifier signal for property **volume** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QPoint(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpoint.html

    **Detailed Description**

    A point is specified by a x coordinate and an y coordinate which can be
    accessed using the **x** () and **y** () functions. The **isNull** ()
    function returns `true` if both x and y are set to 0. The coordinates can be
    set (or altered) using the **setX** () and **setY** () functions, or
    alternatively the **rx** () and **ry** () functions which return references
    to the coordinates (allowing direct manipulation).

    Given a point **p** , the following statements are all equivalent:

    **QPoint**  p;

        p.setX(p.x() + 1);
        p += **QPoint** (1, 0);
    p.rx()++;

    A QPoint object can also be used as a vector: Addition and subtraction are
    defined as for vectors (each component is added separately). A QPoint object
    can also be divided or multiplied by an `int` or a `qreal`.

    In addition, the QPoint class provides the **manhattanLength** () function
    which gives an inexpensive approximation of the length of the QPoint object
    interpreted as a vector. Finally, QPoint objects can be streamed as well as
    compared.

    **See also** **QPointF**  and **QPolygon** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpoint.html#QPoint

        **QPoint::QPoint()**

        Constructs a null point, i.e. with coordinates (0, 0)

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, xpos: int, ypos: int) -> None:
        """
        https://doc.qt.io/qt-6/qpoint.html#QPoint-1

        **QPoint::QPoint(int xpos , int ypos )**

        Constructs a point with the given coordinates ( **xpos** , **ypos** ).

        **See also** **setX** () and **setY** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QPoint") -> None:
        """
        https://doc.qt.io/qt-6/qpoint.html#QPoint

        **QPoint::QPoint()**

        Constructs a null point, i.e. with coordinates (0, 0)

        **See also** **isNull** ().
        """
        ...

    def __pos__(self) -> "QPoint":
        ...

    def __neg__(self) -> "QPoint":
        ...

    def transposed(self) -> "QPoint":
        """
        https://doc.qt.io/qt-6/qpoint.html#transposed

        **[since 5.14] QPoint QPoint::transposed() const**

        Returns a point with x and y coordinates exchanged:

        **QPoint** {1, 2}.transposed() // {2, 1}

        This function was introduced in Qt 5.14.

        **See also** **x** (), **y** (), **setX** (), and **setY** ().
        """
        ...

    @staticmethod
    def dotProduct(p1: "QPoint", p2: "QPoint") -> int:
        """
        https://doc.qt.io/qt-6/qpoint.html#dotProduct

        **[static, since 5.1] int QPoint::dotProduct(const QPoint & p1 , const
        QPoint & p2 )**

        **QPoint**  p( 3, 7);
            **QPoint**  q(-1, 4);
            int lengthSquared =
        **QPoint** ::dotProduct(p, q);   // lengthSquared becomes 25

        Returns the dot product of **p1** and **p2**.

        This function was introduced in Qt 5.1.
        """
        ...

    def setY(self, ypos: int) -> None:
        """
        https://doc.qt.io/qt-6/qpoint.html#setY

        **void QPoint::setY(int y )**

        Sets the y coordinate of this point to the given **y** coordinate.

        **See also** **y** () and **setX** ().
        """
        ...

    def setX(self, xpos: int) -> None:
        """
        https://doc.qt.io/qt-6/qpoint.html#setX

        **void QPoint::setX(int x )**

        Sets the x coordinate of this point to the given **x** coordinate.

        **See also** **x** () and **setY** ().
        """
        ...

    def y(self) -> int:
        """
        https://doc.qt.io/qt-6/qpoint.html#y

        **int QPoint::y() const**

        Returns the y coordinate of this point.

        **See also** **setY** () and **ry** ().
        """
        ...

    def x(self) -> int:
        """
        https://doc.qt.io/qt-6/qpoint.html#x

        **int QPoint::x() const**

        Returns the x coordinate of this point.

        **See also** **setX** () and **rx** ().
        """
        ...

    def __hash__(self) -> int:
        ...

    def __bool__(self) -> int:
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpoint.html#isNull

        **bool QPoint::isNull() const**

        Returns `true` if both the x and y coordinates are set to 0, otherwise
        returns `false`.
        """
        ...

    def __repr__(self) -> str:
        ...

    def manhattanLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qpoint.html#manhattanLength

        **int QPoint::manhattanLength() const**

        Returns the sum of the absolute values of **x** () and **y** (),
        traditionally known as the "Manhattan length" of the vector from the
        origin to the point. For example:

        **QPoint**  oldPosition;
        MyWidget::mouseMoveEvent(**QMouseEvent**  *event)
            {
        **QPoint**  point = event->pos() - oldPosition;
                if
        (point.manhattanLength() > 3)
                    // the mouse has moved more
        than 3 pixels since the oldPosition
            }

        This is a useful, and quick to calculate, approximation to the true
        length:

        double trueLength = std::sqrt(std::pow(x(), 2) + std::pow(y(), 2));

        The tradition of "Manhattan length" arises because such distances apply
        to travelers who can only travel on a rectangular grid, like the streets
        of Manhattan.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtQml
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *
import enum


class QQuickView(QQuickWindow):
    """
    https://doc.qt.io/qt-6/qquickview.html

    **Detailed Description**

    This is a convenience subclass of **QQuickWindow**  which will automatically
    load and display a QML scene when given the URL of the main source file.
    Alternatively, you can instantiate your own objects using **QQmlComponent**
    and place them in a manually setup **QQuickWindow** .

    Typical usage:

    int main(int argc, char *argv[])
        {
            **QGuiApplication**
    app(argc, argv);

            **QQuickView**  *view = new **QQuickView** ;
    view->setSource(**QUrl** ::fromLocalFile("myqmlfile.qml"));
    view->show();
            return app.exec();
        }

    To receive errors related to loading and executing QML with QQuickView, you
    can connect to the **statusChanged** () signal and monitor for
    **QQuickView::Error** . The errors are available via **QQuickView::errors**
    ().

    QQuickView also manages sizing of the view and root object. By default, the
    **resizeMode**  is **SizeViewToRootObject** , which will load the component
    and resize it to the size of the view. Alternatively the **resizeMode**  may
    be set to **SizeRootObjectToView**  which will resize the view to the size
    of the root object.

    **See also** **Exposing Attributes of C++ Types to QML**  and
    **QQuickWidget** .
    """

    class Status(enum.Enum):
        Null: QQuickView = ...
        Ready: QQuickView = ...
        Loading: QQuickView = ...
        Error: QQuickView = ...

    class ResizeMode(enum.Enum):
        SizeViewToRootObject: QQuickView = ...
        SizeRootObjectToView: QQuickView = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtGui.QWindow] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#QQuickView

        **QQuickView::QQuickView(QWindow * parent = nullptr)**

        Constructs a QQuickView with the given **parent**. The default value of
        **parent** is 0.
        """
        ...

    @typing.overload
    def __init__(self, engine: QtQml.QQmlEngine, parent: QtGui.QWindow) -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#QQuickView-1

        **QQuickView::QQuickView(QQmlEngine * engine , QWindow * parent )**

        Constructs a QQuickView with the given QML **engine** and **parent**.

        Note: In this case, the QQuickView does not own the given **engine**
        object; it is the caller's responsibility to destroy the engine. If the
        **engine** is deleted before the view, **status** () will return
        **QQuickView::Error** .

        **See also** **Status** , **status** (), and **errors** ().
        """
        ...

    @typing.overload
    def __init__(
        self, source: QtCore.QUrl, parent: typing.Optional[QtGui.QWindow] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#QQuickView-2

        **QQuickView::QQuickView(const QUrl & source , QWindow * parent =
        nullptr)**

        Constructs a QQuickView with the given QML **source** and **parent**.
        The default value of **parent** is 0.
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#mouseMoveEvent

        **[override virtual protected] void
        QQuickView::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QQuickWindow::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mouseReleaseEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#mouseReleaseEvent

        **[override virtual protected] void
        QQuickView::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QQuickWindow::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#mousePressEvent

        **[override virtual protected] void
        QQuickView::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QQuickWindow::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def keyReleaseEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#keyReleaseEvent

        **[override virtual protected] void
        QQuickView::keyReleaseEvent(QKeyEvent * e )**

        Reimplements: **QQuickWindow::keyReleaseEvent** (QKeyEvent *e).
        """
        ...

    def keyPressEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#keyPressEvent

        **[override virtual protected] void QQuickView::keyPressEvent(QKeyEvent
        * e )**

        Reimplements: **QQuickWindow::keyPressEvent** (QKeyEvent *e).
        """
        ...

    def timerEvent(self, a0: QtCore.QTimerEvent) -> None:
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        ...

    def setInitialProperties(
        self, initialProperties: typing.Dict[str, typing.Any]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#setInitialProperties

        **[slot, since 5.14] void QQuickView::setInitialProperties(const
        QVariantMap & initialProperties )**

        Sets the initial properties **initialProperties** with which the QML
        component gets initialized after calling **QQuickView::setSource** ().

        **QScopedPointer** <**QQuickView** > view { new **QQuickView**  };
        view->setInitialProperties({"x, 100"}, {"width", 50});
        view->setSource(**QUrl** ::fromLocalFile("myqmlfile.qml"));
        view->show();

        **Note:** You can only use this function to initialize top-level
        properties.

        **Note:** This function should always be called before **setSource** ,
        as it has no effect once the component has become `Ready`.

        This function was introduced in Qt 5.14.

        **See also** **QQmlComponent::createWithInitialProperties** ().
        """
        ...

    def setSource(self, a0: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#setSource

        **[slot] void QQuickView::setSource(const QUrl & url )**

        Sets the source to the **url** , loads the QML component and
        instantiates it.

        Ensure that the URL provided is full and correct, in particular, use
        **QUrl::fromLocalFile** () when loading a file from the local
        filesystem.

        Calling this method multiple times with the same url will result in the
        QML component being reinstantiated.

        **Note:** Setter function for property **source** .

        **See also** **source** ().
        """
        ...

    def initialSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qquickview.html#initialSize

        **QSize QQuickView::initialSize() const**

        Returns the initial size of the root object.

        If **resizeMode**  is QQuickItem::SizeRootObjectToView the root object
        will be resized to the size of the view. initialSize contains the size
        of the root object before it was resized.
        """
        ...

    def errors(self) -> typing.List[QtQml.QQmlError]:
        """
        https://doc.qt.io/qt-6/qquickview.html#errors

        **QList<QQmlError> QQuickView::errors() const**

        Return the list of errors that occurred during the last compile or
        create operation. When the status is not Error, an empty list is
        returned.
        """
        ...

    def status(self) -> "QQuickView.Status":
        """
        https://doc.qt.io/qt-6/qquickview.html#status-prop

        **[read-only] status : const Status**

        The component's current **status** .

        **Access functions:**

        QQuickView::Status **status** () const

        **Notifier signal:**

        void ****statusChanged** ** (QQuickView::Status **status** )

        **Member Function Documentation**
        """
        ...

    def setResizeMode(self, a0: "QQuickView.ResizeMode") -> None:
        """
        https://doc.qt.io/qt-6/qquickview.html#resizeMode-prop

        **resizeMode : ResizeMode**

        This property holds whether the view should resize the window contents

        If this property is set to **SizeViewToRootObject**  (the default), the
        view resizes to the size of the root item in the QML.

        If this property is set to **SizeRootObjectToView** , the view will
        automatically resize the root item to the size of the view.

        **Access functions:**

        QQuickView::ResizeMode **resizeMode** () const
        void **setResizeMode**
        (QQuickView::ResizeMode)

        **See also** **initialSize** ().
        """
        ...

    def resizeMode(self) -> "QQuickView.ResizeMode":
        """
        https://doc.qt.io/qt-6/qquickview.html#resizeMode-prop

        **resizeMode : ResizeMode**

        This property holds whether the view should resize the window contents

        If this property is set to **SizeViewToRootObject**  (the default), the
        view resizes to the size of the root item in the QML.

        If this property is set to **SizeRootObjectToView** , the view will
        automatically resize the root item to the size of the view.

        **Access functions:**

        QQuickView::ResizeMode **resizeMode** () const
        void **setResizeMode**
        (QQuickView::ResizeMode)

        **See also** **initialSize** ().
        """
        ...

    def rootObject(self) -> QQuickItem:
        """
        https://doc.qt.io/qt-6/qquickview.html#rootObject

        **QQuickItem *QQuickView::rootObject() const**

        Returns the view's root **item** .
        """
        ...

    def rootContext(self) -> QtQml.QQmlContext:
        """
        https://doc.qt.io/qt-6/qquickview.html#rootContext

        **QQmlContext *QQuickView::rootContext() const**

        This function returns the root of the context hierarchy. Each QML
        component is instantiated in a **QQmlContext** . **QQmlContext** 's are
        essential for passing data to QML components. In QML, contexts are
        arranged hierarchically and this hierarchy is managed by the
        **QQmlEngine** .
        """
        ...

    def engine(self) -> QtQml.QQmlEngine:
        """
        https://doc.qt.io/qt-6/qquickview.html#engine

        **QQmlEngine *QQuickView::engine() const**

        Returns a pointer to the **QQmlEngine**  used for instantiating QML
        Components.
        """
        ...

    def source(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qquickview.html#source

        **QUrl QQuickView::source() const**

        Returns the source URL, if set.

        **Note:** Getter function for property source.

        **See also** **setSource** ().
        """
        ...

    @property
    def statusChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qquickview.html#statusChanged

        **[signal] void QQuickView::statusChanged(QQuickView::Status status )**

        This signal is emitted when the component's current **status** changes.

        **Note:** Notifier signal for property **status** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QIconDragEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qicondragevent.html

    **Detailed Description**

    Icon drag events are sent to widgets when the main icon of a window has been
    dragged away. On macOS, this happens when the proxy icon of a window is
    dragged off the title bar.

    It is normal to begin using drag and drop in response to this event.

    **See also** **Drag and Drop** , **QMimeData** , and **QDrag** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qicondragevent.html#QIconDragEvent-2

        **QIconDragEvent::QIconDragEvent()**

        Constructs an icon drag event object with the accept flag set to false.

        **See also** **accept** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._functions import QWIDGETSIZE_MAX as QWIDGETSIZE_MAX
from ._functions import qDrawBorderPixmap as qDrawBorderPixmap
from ._functions import qDrawPlainRect as qDrawPlainRect
from ._functions import qDrawPlainRect as qDrawPlainRect
from ._functions import qDrawWinPanel as qDrawWinPanel
from ._functions import qDrawWinPanel as qDrawWinPanel
from ._functions import qDrawWinButton as qDrawWinButton
from ._functions import qDrawWinButton as qDrawWinButton
from ._functions import qDrawShadePanel as qDrawShadePanel
from ._functions import qDrawShadePanel as qDrawShadePanel
from ._functions import qDrawShadeRect as qDrawShadeRect
from ._functions import qDrawShadeRect as qDrawShadeRect
from ._functions import qDrawShadeLine as qDrawShadeLine
from ._functions import qDrawShadeLine as qDrawShadeLine
from ._QWidget import QWidget as QWidget
from ._QAbstractButton import QAbstractButton as QAbstractButton
from ._QAbstractItemDelegate import QAbstractItemDelegate as QAbstractItemDelegate
from ._QFrame import QFrame as QFrame
from ._QAbstractScrollArea import QAbstractScrollArea as QAbstractScrollArea
from ._QAbstractItemView import QAbstractItemView as QAbstractItemView
from ._QAbstractSlider import QAbstractSlider as QAbstractSlider
from ._QAbstractSpinBox import QAbstractSpinBox as QAbstractSpinBox
from ._QApplication import QApplication as QApplication
from ._QLayoutItem import QLayoutItem as QLayoutItem
from ._QLayout import QLayout as QLayout
from ._QBoxLayout import QBoxLayout as QBoxLayout
from ._QHBoxLayout import QHBoxLayout as QHBoxLayout
from ._QVBoxLayout import QVBoxLayout as QVBoxLayout
from ._QButtonGroup import QButtonGroup as QButtonGroup
from ._QCalendarWidget import QCalendarWidget as QCalendarWidget
from ._QCheckBox import QCheckBox as QCheckBox
from ._QDialog import QDialog as QDialog
from ._QColorDialog import QColorDialog as QColorDialog
from ._QColumnView import QColumnView as QColumnView
from ._QComboBox import QComboBox as QComboBox
from ._QPushButton import QPushButton as QPushButton
from ._QCommandLinkButton import QCommandLinkButton as QCommandLinkButton
from ._QStyle import QStyle as QStyle
from ._QCommonStyle import QCommonStyle as QCommonStyle
from ._QCompleter import QCompleter as QCompleter
from ._QDataWidgetMapper import QDataWidgetMapper as QDataWidgetMapper
from ._QDateTimeEdit import QDateTimeEdit as QDateTimeEdit
from ._QTimeEdit import QTimeEdit as QTimeEdit
from ._QDateEdit import QDateEdit as QDateEdit
from ._QDial import QDial as QDial
from ._QDialogButtonBox import QDialogButtonBox as QDialogButtonBox
from ._QDockWidget import QDockWidget as QDockWidget
from ._QErrorMessage import QErrorMessage as QErrorMessage
from ._QFileDialog import QFileDialog as QFileDialog
from ._QFileIconProvider import QFileIconProvider as QFileIconProvider
from ._QFocusFrame import QFocusFrame as QFocusFrame
from ._QFontComboBox import QFontComboBox as QFontComboBox
from ._QFontDialog import QFontDialog as QFontDialog
from ._QFormLayout import QFormLayout as QFormLayout
from ._QGesture import QGesture as QGesture
from ._QPanGesture import QPanGesture as QPanGesture
from ._QPinchGesture import QPinchGesture as QPinchGesture
from ._QSwipeGesture import QSwipeGesture as QSwipeGesture
from ._QTapGesture import QTapGesture as QTapGesture
from ._QTapAndHoldGesture import QTapAndHoldGesture as QTapAndHoldGesture
from ._QGestureEvent import QGestureEvent as QGestureEvent
from ._QGestureRecognizer import QGestureRecognizer as QGestureRecognizer
from ._QGraphicsAnchor import QGraphicsAnchor as QGraphicsAnchor
from ._QGraphicsLayoutItem import QGraphicsLayoutItem as QGraphicsLayoutItem
from ._QGraphicsLayout import QGraphicsLayout as QGraphicsLayout
from ._QGraphicsAnchorLayout import QGraphicsAnchorLayout as QGraphicsAnchorLayout
from ._QGraphicsEffect import QGraphicsEffect as QGraphicsEffect
from ._QGraphicsColorizeEffect import QGraphicsColorizeEffect as QGraphicsColorizeEffect
from ._QGraphicsBlurEffect import QGraphicsBlurEffect as QGraphicsBlurEffect
from ._QGraphicsDropShadowEffect import (
    QGraphicsDropShadowEffect as QGraphicsDropShadowEffect,
)
from ._QGraphicsOpacityEffect import QGraphicsOpacityEffect as QGraphicsOpacityEffect
from ._QGraphicsGridLayout import QGraphicsGridLayout as QGraphicsGridLayout
from ._QGraphicsItem import QGraphicsItem as QGraphicsItem
from ._QAbstractGraphicsShapeItem import (
    QAbstractGraphicsShapeItem as QAbstractGraphicsShapeItem,
)
from ._QGraphicsPathItem import QGraphicsPathItem as QGraphicsPathItem
from ._QGraphicsRectItem import QGraphicsRectItem as QGraphicsRectItem
from ._QGraphicsEllipseItem import QGraphicsEllipseItem as QGraphicsEllipseItem
from ._QGraphicsPolygonItem import QGraphicsPolygonItem as QGraphicsPolygonItem
from ._QGraphicsLineItem import QGraphicsLineItem as QGraphicsLineItem
from ._QGraphicsPixmapItem import QGraphicsPixmapItem as QGraphicsPixmapItem
from ._QGraphicsSimpleTextItem import QGraphicsSimpleTextItem as QGraphicsSimpleTextItem
from ._QGraphicsItemGroup import QGraphicsItemGroup as QGraphicsItemGroup
from ._QGraphicsObject import QGraphicsObject as QGraphicsObject
from ._QGraphicsTextItem import QGraphicsTextItem as QGraphicsTextItem
from ._QGraphicsLinearLayout import QGraphicsLinearLayout as QGraphicsLinearLayout
from ._QGraphicsWidget import QGraphicsWidget as QGraphicsWidget
from ._QGraphicsProxyWidget import QGraphicsProxyWidget as QGraphicsProxyWidget
from ._QGraphicsScene import QGraphicsScene as QGraphicsScene
from ._QGraphicsSceneEvent import QGraphicsSceneEvent as QGraphicsSceneEvent
from ._QGraphicsSceneMouseEvent import (
    QGraphicsSceneMouseEvent as QGraphicsSceneMouseEvent,
)
from ._QGraphicsSceneWheelEvent import (
    QGraphicsSceneWheelEvent as QGraphicsSceneWheelEvent,
)
from ._QGraphicsSceneContextMenuEvent import (
    QGraphicsSceneContextMenuEvent as QGraphicsSceneContextMenuEvent,
)
from ._QGraphicsSceneHoverEvent import (
    QGraphicsSceneHoverEvent as QGraphicsSceneHoverEvent,
)
from ._QGraphicsSceneHelpEvent import QGraphicsSceneHelpEvent as QGraphicsSceneHelpEvent
from ._QGraphicsSceneDragDropEvent import (
    QGraphicsSceneDragDropEvent as QGraphicsSceneDragDropEvent,
)
from ._QGraphicsSceneResizeEvent import (
    QGraphicsSceneResizeEvent as QGraphicsSceneResizeEvent,
)
from ._QGraphicsSceneMoveEvent import QGraphicsSceneMoveEvent as QGraphicsSceneMoveEvent
from ._QGraphicsTransform import QGraphicsTransform as QGraphicsTransform
from ._QGraphicsScale import QGraphicsScale as QGraphicsScale
from ._QGraphicsRotation import QGraphicsRotation as QGraphicsRotation
from ._QGraphicsView import QGraphicsView as QGraphicsView
from ._QGridLayout import QGridLayout as QGridLayout
from ._QGroupBox import QGroupBox as QGroupBox
from ._QHeaderView import QHeaderView as QHeaderView
from ._QInputDialog import QInputDialog as QInputDialog
from ._QItemDelegate import QItemDelegate as QItemDelegate
from ._QItemEditorCreatorBase import QItemEditorCreatorBase as QItemEditorCreatorBase
from ._QItemEditorFactory import QItemEditorFactory as QItemEditorFactory
from ._QKeySequenceEdit import QKeySequenceEdit as QKeySequenceEdit
from ._QLabel import QLabel as QLabel
from ._QSpacerItem import QSpacerItem as QSpacerItem
from ._QWidgetItem import QWidgetItem as QWidgetItem
from ._QLCDNumber import QLCDNumber as QLCDNumber
from ._QLineEdit import QLineEdit as QLineEdit
from ._QListView import QListView as QListView
from ._QListWidgetItem import QListWidgetItem as QListWidgetItem
from ._QListWidget import QListWidget as QListWidget
from ._QMainWindow import QMainWindow as QMainWindow
from ._QMdiArea import QMdiArea as QMdiArea
from ._QMdiSubWindow import QMdiSubWindow as QMdiSubWindow
from ._QMenu import QMenu as QMenu
from ._QMenuBar import QMenuBar as QMenuBar
from ._QMessageBox import QMessageBox as QMessageBox
from ._QPlainTextEdit import QPlainTextEdit as QPlainTextEdit
from ._QPlainTextDocumentLayout import (
    QPlainTextDocumentLayout as QPlainTextDocumentLayout,
)
from ._QProgressBar import QProgressBar as QProgressBar
from ._QProgressDialog import QProgressDialog as QProgressDialog
from ._QProxyStyle import QProxyStyle as QProxyStyle
from ._QRadioButton import QRadioButton as QRadioButton
from ._QRubberBand import QRubberBand as QRubberBand
from ._QScrollArea import QScrollArea as QScrollArea
from ._QScrollBar import QScrollBar as QScrollBar
from ._QScroller import QScroller as QScroller
from ._QScrollerProperties import QScrollerProperties as QScrollerProperties
from ._QSizeGrip import QSizeGrip as QSizeGrip
from ._QSizePolicy import QSizePolicy as QSizePolicy
from ._QSlider import QSlider as QSlider
from ._QSpinBox import QSpinBox as QSpinBox
from ._QDoubleSpinBox import QDoubleSpinBox as QDoubleSpinBox
from ._QSplashScreen import QSplashScreen as QSplashScreen
from ._QSplitter import QSplitter as QSplitter
from ._QSplitterHandle import QSplitterHandle as QSplitterHandle
from ._QStackedLayout import QStackedLayout as QStackedLayout
from ._QStackedWidget import QStackedWidget as QStackedWidget
from ._QStatusBar import QStatusBar as QStatusBar
from ._QStyledItemDelegate import QStyledItemDelegate as QStyledItemDelegate
from ._QStyleFactory import QStyleFactory as QStyleFactory
from ._QStyleOption import QStyleOption as QStyleOption
from ._QStyleOptionFocusRect import QStyleOptionFocusRect as QStyleOptionFocusRect
from ._QStyleOptionFrame import QStyleOptionFrame as QStyleOptionFrame
from ._QStyleOptionTabWidgetFrame import (
    QStyleOptionTabWidgetFrame as QStyleOptionTabWidgetFrame,
)
from ._QStyleOptionTabBarBase import QStyleOptionTabBarBase as QStyleOptionTabBarBase
from ._QStyleOptionHeader import QStyleOptionHeader as QStyleOptionHeader
from ._QStyleOptionHeaderV2 import QStyleOptionHeaderV2 as QStyleOptionHeaderV2
from ._QStyleOptionButton import QStyleOptionButton as QStyleOptionButton
from ._QStyleOptionTab import QStyleOptionTab as QStyleOptionTab
from ._QStyleOptionProgressBar import QStyleOptionProgressBar as QStyleOptionProgressBar
from ._QStyleOptionMenuItem import QStyleOptionMenuItem as QStyleOptionMenuItem
from ._QStyleOptionDockWidget import QStyleOptionDockWidget as QStyleOptionDockWidget
from ._QStyleOptionViewItem import QStyleOptionViewItem as QStyleOptionViewItem
from ._QStyleOptionToolBox import QStyleOptionToolBox as QStyleOptionToolBox
from ._QStyleOptionRubberBand import QStyleOptionRubberBand as QStyleOptionRubberBand
from ._QStyleOptionComplex import QStyleOptionComplex as QStyleOptionComplex
from ._QStyleOptionSlider import QStyleOptionSlider as QStyleOptionSlider
from ._QStyleOptionSpinBox import QStyleOptionSpinBox as QStyleOptionSpinBox
from ._QStyleOptionToolButton import QStyleOptionToolButton as QStyleOptionToolButton
from ._QStyleOptionComboBox import QStyleOptionComboBox as QStyleOptionComboBox
from ._QStyleOptionTitleBar import QStyleOptionTitleBar as QStyleOptionTitleBar
from ._QStyleHintReturn import QStyleHintReturn as QStyleHintReturn
from ._QStyleHintReturnMask import QStyleHintReturnMask as QStyleHintReturnMask
from ._QStyleOptionToolBar import QStyleOptionToolBar as QStyleOptionToolBar
from ._QStyleOptionGroupBox import QStyleOptionGroupBox as QStyleOptionGroupBox
from ._QStyleOptionSizeGrip import QStyleOptionSizeGrip as QStyleOptionSizeGrip
from ._QStyleOptionGraphicsItem import (
    QStyleOptionGraphicsItem as QStyleOptionGraphicsItem,
)
from ._QStyleHintReturnVariant import QStyleHintReturnVariant as QStyleHintReturnVariant
from ._QStylePainter import QStylePainter as QStylePainter
from ._QSystemTrayIcon import QSystemTrayIcon as QSystemTrayIcon
from ._QTabBar import QTabBar as QTabBar
from ._QTableView import QTableView as QTableView
from ._QTableWidgetSelectionRange import (
    QTableWidgetSelectionRange as QTableWidgetSelectionRange,
)
from ._QTableWidgetItem import QTableWidgetItem as QTableWidgetItem
from ._QTableWidget import QTableWidget as QTableWidget
from ._QTabWidget import QTabWidget as QTabWidget
from ._QTextEdit import QTextEdit as QTextEdit
from ._QTextBrowser import QTextBrowser as QTextBrowser
from ._QToolBar import QToolBar as QToolBar
from ._QToolBox import QToolBox as QToolBox
from ._QToolButton import QToolButton as QToolButton
from ._QToolTip import QToolTip as QToolTip
from ._QTreeView import QTreeView as QTreeView
from ._QTreeWidgetItem import QTreeWidgetItem as QTreeWidgetItem
from ._QTreeWidget import QTreeWidget as QTreeWidget
from ._QTreeWidgetItemIterator import QTreeWidgetItemIterator as QTreeWidgetItemIterator
from ._QUndoView import QUndoView as QUndoView
from ._QWhatsThis import QWhatsThis as QWhatsThis
from ._QWidgetAction import QWidgetAction as QWidgetAction
from ._QWizard import QWizard as QWizard
from ._QWizardPage import QWizardPage as QWizardPage



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsObject(QtCore.QObject, QGraphicsItem):
    """
    https://doc.qt.io/qt-6/qgraphicsobject.html

    **Detailed Description**

    The class extends a **QGraphicsItem**  with **QObject** 's signal/slot and
    property mechanisms. It maps many of **QGraphicsItem** 's basic setters and
    getters to properties and adds notification signals for many of them.

    **Parents and Children**

    Each graphics object can be constructed with a parent item. This ensures
    that the item will be destroyed when its parent item is destroyed. Although
    QGraphicsObject inherits from both **QObject**  and **QGraphicsItem** , you
    should use the functions provided by **QGraphicsItem** , **not** **QObject**
    , to manage the relationships between parent and child items.

    The relationships between items can be explored using the **parentItem** ()
    and **childItems** () functions. In the hierarchy of items in a scene, the
    **parentObject** () and **parentWidget** () functions are the equivalent of
    the **QWidget::parent** () and **QWidget::parentWidget** () functions for
    **QWidget**  subclasses.

    **See also** **QGraphicsWidget** .
    """

    def __init__(self, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#QGraphicsObject

        **QGraphicsObject::QGraphicsObject(QGraphicsItem * parent = nullptr)**

        Constructs a QGraphicsObject with **parent**.
        """
        ...

    def event(self, ev: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#event

        **[override virtual protected] bool QGraphicsObject::event(QEvent * ev
        )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def updateMicroFocus(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#updateMicroFocus

        **[protected slot] void QGraphicsObject::updateMicroFocus()**

        Updates the item's micro focus. This is slot for convenience.

        **See also** **QInputMethod** .
        """
        ...

    def ungrabGesture(self, type: QtCore.Qt.GestureType) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#ungrabGesture

        **void QGraphicsObject::ungrabGesture(Qt::GestureType gesture )**

        Unsubscribes the graphics object from the given **gesture**.

        **See also** **grabGesture** () and **QGestureEvent** .
        """
        ...

    def grabGesture(
        self, type: QtCore.Qt.GestureType, flags: QtCore.Qt.GestureFlag = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#grabGesture

        **void QGraphicsObject::grabGesture(Qt::GestureType gesture ,
        Qt::GestureFlags flags = Qt::GestureFlags())**

        Subscribes the graphics object to the given **gesture** with specific
        **flags**.

        **See also** **ungrabGesture** () and **QGestureEvent** .
        """
        ...

    @property
    def enabledChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#enabledChanged

        **[signal] void QGraphicsObject::enabledChanged()**

        This signal gets emitted whenever the item gets enabled or disabled.

        **Note:** Notifier signal for property **enabled** .

        **See also** **isEnabled** ().
        """
        ...

    @property
    def opacityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#opacityChanged

        **[signal] void QGraphicsObject::opacityChanged()**

        This signal gets emitted whenever the opacity of the item changes

        **Note:** Notifier signal for property **opacity** .

        **See also** **QGraphicsItem::opacity** ().
        """
        ...

    @property
    def parentChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#parentChanged

        **[signal] void QGraphicsObject::parentChanged()**

        This signal gets emitted whenever the parent of the item changes

        **Note:** Notifier signal for property **parent** .
        """
        ...

    @property
    def rotationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#rotationChanged

        **[signal] void QGraphicsObject::rotationChanged()**

        This signal gets emitted whenever the rotation of the item changes.

        **Note:** Notifier signal for property **rotation** .
        """
        ...

    @property
    def scaleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#scaleChanged

        **[signal] void QGraphicsObject::scaleChanged()**

        This signal is emitted when the scale of the item changes.

        **Note:** Notifier signal for property **scale** .
        """
        ...

    @property
    def visibleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#visibleChanged

        **[signal] void QGraphicsObject::visibleChanged()**

        This signal gets emitted whenever the visibility of the item changes

        **Note:** Notifier signal for property **visible** .

        **See also** **visible** .
        """
        ...

    @property
    def xChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#xChanged

        **[signal] void QGraphicsObject::xChanged()**

        This signal gets emitted whenever the x position of the item changes

        **Note:** Notifier signal for property **x** .

        **See also** **pos** ().
        """
        ...

    @property
    def yChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#yChanged

        **[signal] void QGraphicsObject::yChanged()**

        This signal gets emitted whenever the y position of the item changes.

        **Note:** Notifier signal for property **y** .

        **See also** **pos** ().
        """
        ...

    @property
    def zChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsobject.html#zChanged

        **[signal] void QGraphicsObject::zChanged()**

        This signal gets emitted whenever the z value of the item changes.

        **Note:** Notifier signal for property **z** .

        **See also** **pos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtWidgets import *
import enum


class QScrollerProperties(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qscrollerproperties.html

    **Detailed Description**

    The QScrollerProperties class stores the parameters used by **QScroller** .

    The default settings are platform dependent so that Qt emulates the platform
    behaviour for kinetic scrolling.

    As a convention the QScrollerProperties are in physical units (meter,
    seconds) and are converted by **QScroller**  using the current DPI.

    **See also** **QScroller** .
    """

    class ScrollMetric(enum.Enum):
        MousePressEventDelay: QScrollerProperties = ...
        DragStartDistance: QScrollerProperties = ...
        DragVelocitySmoothingFactor: QScrollerProperties = ...
        AxisLockThreshold: QScrollerProperties = ...
        ScrollingCurve: QScrollerProperties = ...
        DecelerationFactor: QScrollerProperties = ...
        MinimumVelocity: QScrollerProperties = ...
        MaximumVelocity: QScrollerProperties = ...
        MaximumClickThroughVelocity: QScrollerProperties = ...
        AcceleratingFlickMaximumTime: QScrollerProperties = ...
        AcceleratingFlickSpeedupFactor: QScrollerProperties = ...
        SnapPositionRatio: QScrollerProperties = ...
        SnapTime: QScrollerProperties = ...
        OvershootDragResistanceFactor: QScrollerProperties = ...
        OvershootDragDistanceFactor: QScrollerProperties = ...
        OvershootScrollDistanceFactor: QScrollerProperties = ...
        OvershootScrollTime: QScrollerProperties = ...
        HorizontalOvershootPolicy: QScrollerProperties = ...
        VerticalOvershootPolicy: QScrollerProperties = ...
        FrameRate: QScrollerProperties = ...
        ScrollMetricCount: QScrollerProperties = ...

    class FrameRates(enum.Enum):
        Standard: QScrollerProperties = ...
        Fps60: QScrollerProperties = ...
        Fps30: QScrollerProperties = ...
        Fps20: QScrollerProperties = ...

    class OvershootPolicy(enum.Enum):
        OvershootWhenScrollable: QScrollerProperties = ...
        OvershootAlwaysOff: QScrollerProperties = ...
        OvershootAlwaysOn: QScrollerProperties = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qscrollerproperties.html#QScrollerProperties

        **QScrollerProperties::QScrollerProperties()**

        Constructs new scroller properties.
        """
        ...

    @typing.overload
    def __init__(self, sp: "QScrollerProperties") -> None:
        """
        https://doc.qt.io/qt-6/qscrollerproperties.html#QScrollerProperties-1

        **QScrollerProperties::QScrollerProperties(const QScrollerProperties &
        sp )**

        Constructs a copy of **sp**.
        """
        ...

    def setScrollMetric(
        self, metric: "QScrollerProperties.ScrollMetric", value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qscrollerproperties.html#setScrollMetric

        **void
        QScrollerProperties::setScrollMetric(QScrollerProperties::ScrollMetric
        metric , const QVariant & value )**

        Set a specific value of the **metric** ScrollerMetric to **value**.

        **See also** **scrollMetric** () and **ScrollMetric** .
        """
        ...

    def scrollMetric(self, metric: "QScrollerProperties.ScrollMetric") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qscrollerproperties.html#scrollMetric

        **QVariant
        QScrollerProperties::scrollMetric(QScrollerProperties::ScrollMetric
        metric ) const**

        Query the **metric** value of the scroller properties.

        **See also** **setScrollMetric** () and **ScrollMetric** .
        """
        ...

    @staticmethod
    def unsetDefaultScrollerProperties() -> None:
        """
        https://doc.qt.io/qt-6/qscrollerproperties.html#unsetDefaultScrollerProp
        erties

        **[static] void QScrollerProperties::unsetDefaultScrollerProperties()**

        Sets the scroller properties returned by the default constructor back to
        the platform default properties.

        **See also** **setDefaultScrollerProperties** ().
        """
        ...

    @staticmethod
    def setDefaultScrollerProperties(sp: "QScrollerProperties") -> None:
        """
        https://doc.qt.io/qt-6/qscrollerproperties.html#setDefaultScrollerProper
        ties

        **[static] void QScrollerProperties::setDefaultScrollerProperties(const
        QScrollerProperties & sp )**

        Sets the scroller properties for all new **QScrollerProperties**
        objects to **sp**.

        Use this function to override the platform default properties returned
        by the default constructor. If you only want to change the scroller
        properties of a single scroller, use
        **QScroller::setScrollerProperties** ()

        **Note:** Calling this function will not change the content of already
        existing **QScrollerProperties**  objects.

        **See also** **unsetDefaultScrollerProperties** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QBoxLayout(QLayout):
    """
    https://doc.qt.io/qt-6/qboxlayout.html

    **Detailed Description**

    QBoxLayout takes the space it gets (from its parent layout or from the
    **parentWidget** ()), divides it up into a row of boxes, and makes each
    managed widget fill one box.

    ![Horizontal box layout with five child widgets](images/qhboxlayout-
    with-5-children.png)

    If the QBoxLayout's orientation is **Qt::Horizontal**  the boxes are placed
    in a row, with suitable sizes. Each widget (or other box) will get at least
    its minimum size and at most its maximum size. Any excess space is shared
    according to the stretch factors (more about that below).

    ![Vertical box layout with five child widgets](images/qvboxlayout-
    with-5-children.png)

    If the QBoxLayout's orientation is **Qt::Vertical** , the boxes are placed
    in a column, again with suitable sizes.

    The easiest way to create a QBoxLayout is to use one of the convenience
    classes, e.g. **QHBoxLayout**  (for **Qt::Horizontal**  boxes) or
    **QVBoxLayout**  (for **Qt::Vertical**  boxes). You can also use the
    QBoxLayout constructor directly, specifying its direction as **LeftToRight**
    , **RightToLeft** , **TopToBottom** , or **BottomToTop** .

    If the QBoxLayout is not the top-level layout (i.e. it is not managing all
    of the widget's area and children), you must add it to its parent layout
    before you can do anything with it. The normal way to add a layout is by
    calling parentLayout->**addLayout** ().

    Once you have done this, you can add boxes to the QBoxLayout using one of
    four functions:

    * **addWidget** () to add a widget to the QBoxLayout and set the widget's
    stretch factor. (The stretch factor is along the row of boxes.)
      *
    **addSpacing** () to create an empty box; this is one of the functions you
    use to create nice and spacious dialogs. See below for ways to set margins.
    * **addStretch** () to create an empty, stretchable box.
      * **addLayout**
    () to add a box containing another **QLayout**  to the row and set that
    layout's stretch factor.

    Use **insertWidget** (), **insertSpacing** (), **insertStretch** () or
    **insertLayout** () to insert a box at a specified position in the layout.

    QBoxLayout also includes two margin widths:

    * **setContentsMargins** () sets the width of the outer border on each side
    of the widget. This is the width of the reserved space along each of the
    QBoxLayout's four sides.
      * **setSpacing** () sets the width between
    neighboring boxes. (You can use **addSpacing** () to get more space at a
    particular spot.)

    The margin default is provided by the style. The default margin most Qt
    styles specify is 9 for child widgets and 11 for windows. The spacing
    defaults to the same as the margin width for a top-level layout, or to the
    same as the parent layout.

    To remove a widget from a layout, call **removeWidget** (). Calling
    **QWidget::hide** () on a widget also effectively removes the widget from
    the layout until **QWidget::show** () is called.

    You will almost always want to use **QVBoxLayout**  and **QHBoxLayout**
    rather than QBoxLayout because of their convenient constructors.

    **See also** **QGridLayout** , **QStackedLayout** , and **Layout
    Management** .
    """

    class Direction(enum.Enum):
        LeftToRight: QBoxLayout = ...
        RightToLeft: QBoxLayout = ...
        TopToBottom: QBoxLayout = ...
        BottomToTop: QBoxLayout = ...
        Down: QBoxLayout = ...
        Up: QBoxLayout = ...

    def __init__(
        self, direction: "QBoxLayout.Direction", parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#QBoxLayout

        **QBoxLayout::QBoxLayout(QBoxLayout::Direction dir , QWidget * parent =
        nullptr)**

        Constructs a new QBoxLayout with direction **dir** and parent widget
        **parent**.

        The layout is set directly as the top-level layout for **parent**. There
        can be only one top-level layout for a widget. It is returned by
        **QWidget::layout** ().

        **See also** **direction** () and **QWidget::setLayout** ().
        """
        ...

    def insertItem(self, index: int, a1: QLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#insertItem

        **void QBoxLayout::insertItem(int index , QLayoutItem * item )**

        Inserts **item** into this box layout at position **index**. If
        **index** is negative, the item is added at the end.

        **See also** **addItem** (), **insertWidget** (), **insertLayout** (),
        **insertStretch** (), and **insertSpacing** ().
        """
        ...

    def stretch(self, index: int) -> int:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#stretch

        **int QBoxLayout::stretch(int index ) const**

        Returns the stretch factor at position **index**.

        **See also** **setStretch** ().
        """
        ...

    def setStretch(self, index: int, stretch: int) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#setStretch

        **void QBoxLayout::setStretch(int index , int stretch )**

        Sets the stretch factor at position **index**. to **stretch**.

        **See also** **stretch** ().
        """
        ...

    def insertSpacerItem(self, index: int, spacerItem: "QSpacerItem") -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#insertSpacerItem

        **void QBoxLayout::insertSpacerItem(int index , QSpacerItem * spacerItem
        )**

        Inserts **spacerItem** at position **index** , with zero minimum size
        and stretch factor. If **index** is negative the space is added at the
        end.

        **See also** **addSpacerItem** (), **insertStretch** (), and
        **insertSpacing** ().
        """
        ...

    def addSpacerItem(self, spacerItem: "QSpacerItem") -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#addSpacerItem

        **void QBoxLayout::addSpacerItem(QSpacerItem * spacerItem )**

        Adds **spacerItem** to the end of this box layout.

        **See also** **addSpacing** () and **addStretch** ().
        """
        ...

    def setSpacing(self, spacing: int) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#setSpacing

        **[override virtual] void QBoxLayout::setSpacing(int spacing )**

        Reimplements an access function for property: **QLayout::spacing** .

        Reimplements **QLayout::setSpacing** (). Sets the spacing property to
        **spacing**.

        **See also** **QLayout::setSpacing** () and **spacing** ().
        """
        ...

    def spacing(self) -> int:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#spacing

        **[override virtual] int QBoxLayout::spacing() const**

        Reimplements an access function for property: **QLayout::spacing** .

        Reimplements **QLayout::spacing** (). If the spacing property is valid,
        that value is returned. Otherwise, a value for the spacing property is
        computed and returned. Since layout spacing in a widget is style
        dependent, if the parent is a widget, it queries the style for the
        (horizontal or vertical) spacing of the layout. Otherwise, the parent is
        a layout, and it queries the parent layout for the spacing().

        **See also** **QLayout::spacing** () and **setSpacing** ().
        """
        ...

    def setGeometry(self, a0: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#setGeometry

        **[override virtual] void QBoxLayout::setGeometry(const QRect & r )**

        Reimplements: **QLayout::setGeometry** (const QRect &r).
        """
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#count

        **[override virtual] int QBoxLayout::count() const**

        Reimplements: **QLayout::count() const** .
        """
        ...

    def takeAt(self, a0: int) -> QLayoutItem:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#takeAt

        **[override virtual] QLayoutItem *QBoxLayout::takeAt(int index )**

        Reimplements: **QLayout::takeAt** (int index).
        """
        ...

    def itemAt(self, a0: int) -> QLayoutItem:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#itemAt

        **[override virtual] QLayoutItem *QBoxLayout::itemAt(int index ) const**

        Reimplements: **QLayout::itemAt(int index) const** .
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#invalidate

        **[override virtual] void QBoxLayout::invalidate()**

        Reimplements: **QLayout::invalidate** ().

        Resets cached information.
        """
        ...

    def expandingDirections(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#expandingDirections

        **[override virtual] Qt::Orientations QBoxLayout::expandingDirections()
        const**

        Reimplements: **QLayout::expandingDirections() const** .
        """
        ...

    def minimumHeightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#minimumHeightForWidth

        **[override virtual] int QBoxLayout::minimumHeightForWidth(int w )
        const**

        Reimplements: **QLayoutItem::minimumHeightForWidth(int w) const** .
        """
        ...

    def heightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#heightForWidth

        **[override virtual] int QBoxLayout::heightForWidth(int w ) const**

        Reimplements: **QLayoutItem::heightForWidth(int) const** .
        """
        ...

    def hasHeightForWidth(self) -> bool:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#hasHeightForWidth

        **[override virtual] bool QBoxLayout::hasHeightForWidth() const**

        Reimplements: **QLayoutItem::hasHeightForWidth() const** .
        """
        ...

    def maximumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#maximumSize

        **[override virtual] QSize QBoxLayout::maximumSize() const**

        Reimplements: **QLayout::maximumSize() const** .
        """
        ...

    def minimumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#minimumSize

        **[override virtual] QSize QBoxLayout::minimumSize() const**

        Reimplements: **QLayout::minimumSize() const** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#sizeHint

        **[override virtual] QSize QBoxLayout::sizeHint() const**

        Reimplements: **QLayoutItem::sizeHint() const** .
        """
        ...

    @typing.overload
    def setStretchFactor(self, w: QWidget, stretch: int) -> bool:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#setStretchFactor

        **bool QBoxLayout::setStretchFactor(QWidget * widget , int stretch )**

        Sets the stretch factor for **widget** to **stretch** and returns true
        if **widget** is found in this layout (not including child layouts);
        otherwise returns `false`.

        **See also** **setAlignment** ().
        """
        ...

    @typing.overload
    def setStretchFactor(self, l: QLayout, stretch: int) -> bool:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#setStretchFactor-1

        **bool QBoxLayout::setStretchFactor(QLayout * layout , int stretch )**

        This is an overloaded function.

        Sets the stretch factor for the layout **layout** to **stretch** and
        returns `true` if **layout** is found in this layout (not including
        child layouts); otherwise returns `false`.
        """
        ...

    def insertLayout(self, index: int, layout: QLayout, stretch: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#insertLayout

        **void QBoxLayout::insertLayout(int index , QLayout * layout , int
        stretch = 0)**

        Inserts **layout** at position **index** , with stretch factor
        **stretch**. If **index** is negative, the layout is added at the end.

        **layout** becomes a child of the box layout.

        **See also** **addLayout** () and **insertItem** ().
        """
        ...

    def insertWidget(
        self,
        index: int,
        widget: QWidget,
        stretch: int = ...,
        alignment: QtCore.Qt.AlignmentFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#insertWidget

        **void QBoxLayout::insertWidget(int index , QWidget * widget , int
        stretch = 0, Qt::Alignment alignment = Qt::Alignment())**

        Inserts **widget** at position **index** , with stretch factor
        **stretch** and alignment **alignment**. If **index** is negative, the
        widget is added at the end.

        The stretch factor applies only in the **direction**  of the
        **QBoxLayout** , and is relative to the other boxes and widgets in this
        **QBoxLayout** . Widgets and boxes with higher stretch factors grow
        more.

        If the stretch factor is 0 and nothing else in the **QBoxLayout**  has a
        stretch factor greater than zero, the space is distributed according to
        the **QWidget** :sizePolicy() of each widget that's involved.

        The alignment is specified by **alignment**. The default alignment is 0,
        which means that the widget fills the entire cell.

        **See also** **addWidget** () and **insertItem** ().
        """
        ...

    def insertStretch(self, index: int, stretch: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#insertStretch

        **void QBoxLayout::insertStretch(int index , int stretch = 0)**

        Inserts a stretchable space (a **QSpacerItem** ) at position **index** ,
        with zero minimum size and stretch factor **stretch**. If **index** is
        negative the space is added at the end.

        **See also** **addStretch** (), **insertItem** (), and **QSpacerItem** .
        """
        ...

    def insertSpacing(self, index: int, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#insertSpacing

        **void QBoxLayout::insertSpacing(int index , int size )**

        Inserts a non-stretchable space (a **QSpacerItem** ) at position
        **index** , with size **size**. If **index** is negative the space is
        added at the end.

        The box layout has default margin and spacing. This function adds
        additional space.

        **See also** **addSpacing** (), **insertItem** (), and **QSpacerItem** .
        """
        ...

    def addItem(self, a0: QLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#addItem

        **[override virtual] void QBoxLayout::addItem(QLayoutItem * item )**

        Reimplements: **QLayout::addItem** (QLayoutItem *item).
        """
        ...

    def addStrut(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#addStrut

        **void QBoxLayout::addStrut(int size )**

        Limits the perpendicular dimension of the box (e.g. height if the box is
        **LeftToRight** ) to a minimum of **size**. Other constraints may
        increase the limit.

        **See also** **addItem** ().
        """
        ...

    def addLayout(self, layout: QLayout, stretch: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#addLayout

        **void QBoxLayout::addLayout(QLayout * layout , int stretch = 0)**

        Adds **layout** to the end of the box, with serial stretch factor
        **stretch**.

        **See also** **insertLayout** (), **addItem** (), and **addWidget** ().
        """
        ...

    def addWidget(
        self, a0: QWidget, stretch: int = ..., alignment: QtCore.Qt.AlignmentFlag = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#addWidget

        **void QBoxLayout::addWidget(QWidget * widget , int stretch = 0,
        Qt::Alignment alignment = Qt::Alignment())**

        Adds **widget** to the end of this box layout, with a stretch factor of
        **stretch** and alignment **alignment**.

        The stretch factor applies only in the **direction**  of the
        **QBoxLayout** , and is relative to the other boxes and widgets in this
        **QBoxLayout** . Widgets and boxes with higher stretch factors grow
        more.

        If the stretch factor is 0 and nothing else in the **QBoxLayout**  has a
        stretch factor greater than zero, the space is distributed according to
        the **QWidget** :sizePolicy() of each widget that's involved.

        The alignment is specified by **alignment**. The default alignment is 0,
        which means that the widget fills the entire cell.

        **See also** **insertWidget** (), **addItem** (), **addLayout** (),
        **addStretch** (), **addSpacing** (), and **addStrut** ().
        """
        ...

    def addStretch(self, stretch: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#addStretch

        **void QBoxLayout::addStretch(int stretch = 0)**

        Adds a stretchable space (a **QSpacerItem** ) with zero minimum size and
        stretch factor **stretch** to the end of this box layout.

        **See also** **insertStretch** (), **addItem** (), and **QSpacerItem** .
        """
        ...

    def addSpacing(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#addSpacing

        **void QBoxLayout::addSpacing(int size )**

        Adds a non-stretchable space (a **QSpacerItem** ) with size **size** to
        the end of this box layout. **QBoxLayout**  provides default margin and
        spacing. This function adds additional space.

        **See also** **insertSpacing** (), **addItem** (), and **QSpacerItem** .
        """
        ...

    def setDirection(self, a0: "QBoxLayout.Direction") -> None:
        """
        https://doc.qt.io/qt-6/qboxlayout.html#setDirection

        **void QBoxLayout::setDirection(QBoxLayout::Direction direction )**

        Sets the direction of this layout to **direction**.

        **See also** **direction** ().
        """
        ...

    def direction(self) -> "QBoxLayout.Direction":
        """
        https://doc.qt.io/qt-6/qboxlayout.html#direction

        **QBoxLayout::Direction QBoxLayout::direction() const**

        Returns the direction of the box. **addWidget** () and **addSpacing** ()
        work in this direction; the stretch stretches in this direction.

        **See also** **setDirection** (), **QBoxLayout::Direction** ,
        **addWidget** (), and **addSpacing** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtHelp import *


class QHelpEngine(QHelpEngineCore):
    """
    https://doc.qt.io/qt-6/qhelpengine.html

    **Detailed Description**
    """

    def __init__(
        self, collectionFile: str, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhelpengine.html#QHelpEngine

        **QHelpEngine::QHelpEngine(const QString & collectionFile , QObject *
        parent = nullptr)**

        Constructs a new help engine with the given **parent**. The help engine
        uses the information stored in the **collectionFile** for providing
        help. If the collection file does not already exist, it will be created.
        """
        ...

    def searchEngine(self) -> "QHelpSearchEngine":
        """
        https://doc.qt.io/qt-6/qhelpengine.html#searchEngine

        **QHelpSearchEngine *QHelpEngine::searchEngine()**

        Returns the default search engine.
        """
        ...

    def indexWidget(self) -> "QHelpIndexWidget":
        """
        https://doc.qt.io/qt-6/qhelpengine.html#indexWidget

        **QHelpIndexWidget *QHelpEngine::indexWidget()**

        Returns the index widget.
        """
        ...

    def contentWidget(self) -> QHelpContentWidget:
        """
        https://doc.qt.io/qt-6/qhelpengine.html#contentWidget

        **QHelpContentWidget *QHelpEngine::contentWidget()**

        Returns the content widget.
        """
        ...

    def indexModel(self) -> "QHelpIndexModel":
        """
        https://doc.qt.io/qt-6/qhelpengine.html#indexModel

        **QHelpIndexModel *QHelpEngine::indexModel() const**

        Returns the index model.
        """
        ...

    def contentModel(self) -> QHelpContentModel:
        """
        https://doc.qt.io/qt-6/qhelpengine.html#contentModel

        **QHelpContentModel *QHelpEngine::contentModel() const**

        Returns the content model.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtQuick import *
import enum


class QSGNode(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qsgnode.html

    **Detailed Description**

    The QSGNode class can be used as a child container. Children are added with
    the **appendChildNode** (), **prependChildNode** (),
    **insertChildNodeBefore** () and **insertChildNodeAfter** (). The order of
    nodes is important as geometry nodes are rendered according to their
    ordering in the scene graph.

    The scene graph nodes contains a mechanism to describe which parts of the
    scene has changed. This includes the combined matrices, accumulated opacity,
    changes to the node hierarchy, and so on. This information can be used for
    optimizations inside the scene graph renderer. For the renderer to properly
    render the nodes, it is important that users call **QSGNode::markDirty** ()
    with the correct flags when nodes are changed. Most of the functions on the
    node classes will implicitly call **markDirty** (). For example,
    **QSGNode::appendChildNode** () will call **markDirty** () passing in
    **QSGNode::DirtyNodeAdded** .

    If nodes change every frame, the **preprocess** () function can be used to
    apply changes to a node for every frame it is rendered. The use of
    **preprocess** () must be explicitly enabled by setting the
    **QSGNode::UsePreprocess**  flag on the node.

    The virtual **isSubtreeBlocked** () function can be used to disable a
    subtree all together. Nodes in a blocked subtree will not be preprocessed()
    and not rendered.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.
    """

    class DirtyStateBit(enum.Flag):
        DirtyMatrix: QSGNode = ...
        DirtyNodeAdded: QSGNode = ...
        DirtyNodeRemoved: QSGNode = ...
        DirtyGeometry: QSGNode = ...
        DirtyMaterial: QSGNode = ...
        DirtyOpacity: QSGNode = ...

    class Flag(enum.Flag):
        OwnedByParent: QSGNode = ...
        UsePreprocess: QSGNode = ...
        OwnsGeometry: QSGNode = ...
        OwnsMaterial: QSGNode = ...
        OwnsOpaqueMaterial: QSGNode = ...

    class NodeType(enum.Enum):
        BasicNodeType: QSGNode = ...
        GeometryNodeType: QSGNode = ...
        TransformNodeType: QSGNode = ...
        ClipNodeType: QSGNode = ...
        OpacityNodeType: QSGNode = ...

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#QSGNode

        **QSGNode::QSGNode()**

        Constructs a new node
        """
        ...

    def preprocess(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#preprocess

        **[virtual] void QSGNode::preprocess()**

        Override this function to do processing on the node before it is
        rendered.

        Preprocessing needs to be explicitly enabled by setting the flag
        **QSGNode::UsePreprocess** . The flag needs to be set before the node is
        added to the scene graph and will cause the preprocess() function to be
        called for every frame the node is rendered.

        **Warning:** Beware of deleting nodes while they are being preprocessed.
        It is possible, with a small performance hit, to delete a single node
        during its own preprocess call. Deleting a subtree which has nodes that
        also use preprocessing may result in a segmentation fault. This is done
        for performance reasons.
        """
        ...

    def setFlags(self, a0: "QSGNode.Flag", enabled: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#setFlags

        **void QSGNode::setFlags(QSGNode::Flags f , bool enabled = true)**

        Sets the flags **f** on this node if **enabled** is true; otherwise
        clears the flags.

        **See also** **flags** ().
        """
        ...

    def setFlag(self, a0: "QSGNode.Flag", enabled: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#setFlag

        **void QSGNode::setFlag(QSGNode::Flag f , bool enabled = true)**

        Sets the flag **f** on this node if **enabled** is true; otherwise
        clears the flag.

        **See also** **flags** ().
        """
        ...

    def flags(self) -> "QSGNode.Flag":
        """
        https://doc.qt.io/qt-6/qsgnode.html#flags

        **QSGNode::Flags QSGNode::flags() const**

        Returns the set of flags for this node.

        **See also** **setFlags** ().
        """
        ...

    def isSubtreeBlocked(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsgnode.html#isSubtreeBlocked

        **[virtual] bool QSGNode::isSubtreeBlocked() const**

        Returns whether this node and its subtree is available for use.

        Blocked subtrees will not get their dirty states updated and they will
        not be rendered.

        The **QSGOpacityNode**  will return a blocked subtree when accumulated
        opacity is 0, for instance.
        """
        ...

    def markDirty(self, bits: "QSGNode.DirtyStateBit") -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#markDirty

        **void QSGNode::markDirty(QSGNode::DirtyState bits )**

        Notifies all connected renderers that the node has dirty **bits**.
        """
        ...

    def type(self) -> "QSGNode.NodeType":
        """
        https://doc.qt.io/qt-6/qsgnode.html#type

        **QSGNode::NodeType QSGNode::type() const**

        Returns the type of this node. The node type must be one of the
        predefined types defined in **QSGNode::NodeType**  and can safely be
        used to cast to the corresponding class.
        """
        ...

    def previousSibling(self) -> "QSGNode":
        """
        https://doc.qt.io/qt-6/qsgnode.html#previousSibling

        **QSGNode *QSGNode::previousSibling() const**

        Returns the node before this in the parent's list of children.

        The children are stored as a linked list.
        """
        ...

    def nextSibling(self) -> "QSGNode":
        """
        https://doc.qt.io/qt-6/qsgnode.html#nextSibling

        **QSGNode *QSGNode::nextSibling() const**

        Returns the node after this in the parent's list of children.

        The children are stored as a linked list.
        """
        ...

    def lastChild(self) -> "QSGNode":
        """
        https://doc.qt.io/qt-6/qsgnode.html#lastChild

        **QSGNode *QSGNode::lastChild() const**

        Returns the last child of this node.

        The children are stored as a linked list.
        """
        ...

    def firstChild(self) -> "QSGNode":
        """
        https://doc.qt.io/qt-6/qsgnode.html#firstChild

        **QSGNode *QSGNode::firstChild() const**

        Returns the first child of this node.

        The children are stored in a linked list.
        """
        ...

    def childAtIndex(self, i: int) -> "QSGNode":
        """
        https://doc.qt.io/qt-6/qsgnode.html#childAtIndex

        **QSGNode *QSGNode::childAtIndex(int i ) const**

        Returns the child at index **i**.

        Children are stored internally as a linked list, so iterating over the
        children via the index is suboptimal.
        """
        ...

    def __len__(self) -> int:
        ...

    def childCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qsgnode.html#childCount

        **int QSGNode::childCount() const**

        Returns the number of child nodes.
        """
        ...

    def insertChildNodeAfter(self, node: "QSGNode", after: "QSGNode") -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#insertChildNodeAfter

        **void QSGNode::insertChildNodeAfter(QSGNode * node , QSGNode * after
        )**

        Inserts **node** to this node's list of children after the node
        specified with **after**.

        Ordering of nodes is important as geometry nodes will be rendered in the
        order they are added to the scene graph.
        """
        ...

    def insertChildNodeBefore(self, node: "QSGNode", before: "QSGNode") -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#insertChildNodeBefore

        **void QSGNode::insertChildNodeBefore(QSGNode * node , QSGNode * before
        )**

        Inserts **node** to this node's list of children before the node
        specified with **before**.

        Ordering of nodes is important as geometry nodes will be rendered in the
        order they are added to the scene graph.
        """
        ...

    def appendChildNode(self, node: "QSGNode") -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#appendChildNode

        **void QSGNode::appendChildNode(QSGNode * node )**

        Appends **node** to this node's list of children.

        Ordering of nodes is important as geometry nodes will be rendered in the
        order they are added to the scene graph.
        """
        ...

    def prependChildNode(self, node: "QSGNode") -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#prependChildNode

        **void QSGNode::prependChildNode(QSGNode * node )**

        Prepends **node** to this node's the list of children.

        Ordering of nodes is important as geometry nodes will be rendered in the
        order they are added to the scene graph.
        """
        ...

    def removeAllChildNodes(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#removeAllChildNodes

        **void QSGNode::removeAllChildNodes()**

        Removes all child nodes from this node's list of children.
        """
        ...

    def removeChildNode(self, node: "QSGNode") -> None:
        """
        https://doc.qt.io/qt-6/qsgnode.html#removeChildNode

        **void QSGNode::removeChildNode(QSGNode * node )**

        Removes **node** from this node's list of children.
        """
        ...

    def parent(self) -> "QSGNode":
        """
        https://doc.qt.io/qt-6/qsgnode.html#parent

        **QSGNode *QSGNode::parent() const**

        Returns the parent node of this node.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsAnchor(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qgraphicsanchor.html

    **Detailed Description**

    The graphics anchor provides an API that enables you to query and manipulate
    the properties an anchor has. When an anchor is added to the layout with
    **QGraphicsAnchorLayout::addAnchor** (), a QGraphicsAnchor instance is
    returned where the properties are initialized to their default values. The
    properties can then be further changed, and they will be picked up the next
    time the layout is activated.

    **See also** **QGraphicsAnchorLayout::anchor** ().
    """

    def sizePolicy(self) -> "QSizePolicy.Policy":
        """
        https://doc.qt.io/qt-6/qgraphicsanchor.html#sizePolicy-prop

        **sizePolicy : QSizePolicy::Policy**

        This property holds the size policy for the **QGraphicsAnchor** .

        By setting the size policy on an anchor you can configure how the anchor
        can resize itself from its preferred spacing. For instance, if the
        anchor has the size policy **QSizePolicy::Minimum** , the spacing is the
        minimum size of the anchor. However, its size can grow up to the anchors
        maximum size. If the default size policy is **QSizePolicy::Fixed** , the
        anchor can neither grow or shrink, which means that the only size the
        anchor can have is the spacing. **QSizePolicy::Fixed**  is the default
        size policy. **QGraphicsAnchor**  always has a minimum spacing of 0 and
        a very large maximum spacing.

        **Access functions:**

        QSizePolicy::Policy **sizePolicy** () const
        void **setSizePolicy**
        (QSizePolicy::Policy **policy** )

        **See also** **QGraphicsAnchor::spacing** .
        """
        ...

    def setSizePolicy(self, policy: "QSizePolicy.Policy") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchor.html#sizePolicy-prop

        **sizePolicy : QSizePolicy::Policy**

        This property holds the size policy for the **QGraphicsAnchor** .

        By setting the size policy on an anchor you can configure how the anchor
        can resize itself from its preferred spacing. For instance, if the
        anchor has the size policy **QSizePolicy::Minimum** , the spacing is the
        minimum size of the anchor. However, its size can grow up to the anchors
        maximum size. If the default size policy is **QSizePolicy::Fixed** , the
        anchor can neither grow or shrink, which means that the only size the
        anchor can have is the spacing. **QSizePolicy::Fixed**  is the default
        size policy. **QGraphicsAnchor**  always has a minimum spacing of 0 and
        a very large maximum spacing.

        **Access functions:**

        QSizePolicy::Policy **sizePolicy** () const
        void **setSizePolicy**
        (QSizePolicy::Policy **policy** )

        **See also** **QGraphicsAnchor::spacing** .
        """
        ...

    def spacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsanchor.html#spacing-prop

        **spacing : qreal**

        This property holds the preferred space between items in the
        **QGraphicsAnchorLayout** .

        Depending on the anchor type, the default spacing is either 0 or a value
        returned from the style.

        **Access functions:**

        qreal **spacing** () const
        void **setSpacing** (qreal **spacing** )
        void **unsetSpacing** ()

        **See also** **QGraphicsAnchorLayout::addAnchor** ().

        **Member Function Documentation**
        """
        ...

    def unsetSpacing(self) -> None:
        ...

    def setSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchor.html#spacing-prop

        **spacing : qreal**

        This property holds the preferred space between items in the
        **QGraphicsAnchorLayout** .

        Depending on the anchor type, the default spacing is either 0 or a value
        returned from the style.

        **Access functions:**

        qreal **spacing** () const
        void **setSpacing** (qreal **spacing** )
        void **unsetSpacing** ()

        **See also** **QGraphicsAnchorLayout::addAnchor** ().

        **Member Function Documentation**
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore


class QMaskGenerator(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qmaskgenerator.html

    **Detailed Description**

    The WebSockets specification as outlined in **RFC 6455**  requires that all
    communication from client to server be masked. This is to prevent malicious
    scripts from attacking badly behaving proxies. For more information about
    the importance of good masking, see **"Talking to Yourself for Fun and
    Profit" by Lin-Shung Huang et al** . By default **QWebSocket**  uses the
    reasonably secure **QRandomGenerator::global** ()->generate() function. The
    best measure against attacks mentioned in the document above, is to use
    **QWebSocket**  over a secure connection ( **wss://** ). In general, always
    be careful to not have 3rd party script access to a **QWebSocket**  in your
    application.
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmaskgenerator.html#QMaskGenerator-1

        **QMaskGenerator::QMaskGenerator(QObject * parent = nullptr)**

        Creates a new QMaskGenerator object with the given optional **QObject**
        **parent**.
        """
        ...

    def nextMask(self) -> int:
        """
        https://doc.qt.io/qt-6/qmaskgenerator.html#nextMask

        **[pure virtual] quint32 QMaskGenerator::nextMask()**

        Returns a new random 32-bit mask. The randomness depends on the RNG used
        to created the mask.
        """
        ...

    def seed(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmaskgenerator.html#seed

        **[pure virtual] bool QMaskGenerator::seed()**

        Initializes the **QMaskGenerator**  by seeding the randomizer. When
        seed() is not called, it depends on the specific implementation of a
        subclass if a default seed is used or no seed is used at all. Returns
        **true** if seeding succeeds, otherwise false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QPaintDeviceWindow(QWindow, QPaintDevice):
    """
    https://doc.qt.io/qt-6/qpaintdevicewindow.html

    **Detailed Description**

    QPaintDeviceWindow is like a regular **QWindow** , with the added
    functionality of being a paint device too. Whenever the content needs to be
    updated, the virtual **paintEvent** () function is called. Subclasses, that
    reimplement this function, can then simply open a **QPainter**  on the
    window.

    **Note:** This class cannot directly be used in applications. It rather
    serves as a base for subclasses like **QOpenGLWindow** .

    **See also** **QOpenGLWindow** .
    """

    def event(self, event: QtCore.QEvent) -> bool:
        ...

    def exposeEvent(self, a0: QExposeEvent) -> None:
        ...

    def metric(self, metric: QPaintDevice.PaintDeviceMetric) -> int:
        ...

    def paintEvent(self, event: QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qpaintdevicewindow.html#paintEvent

        **[override virtual protected] void
        QPaintDeviceWindow::paintEvent(QPaintEvent * event )**

        Reimplements: **QWindow::paintEvent** (QPaintEvent *ev).

        Handles paint events passed in the **event** parameter.

        The default implementation does nothing. Reimplement this function to
        perform painting. If necessary, the dirty area is retrievable from the
        **event**.
        """
        ...

    @typing.overload
    def update(self, rect: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qpaintdevicewindow.html#update

        **void QPaintDeviceWindow::update(const QRect & rect )**

        Marks the **rect** of the window as dirty and schedules a repaint.

        **Note:** Subsequent calls to this function before the next paint event
        will get ignored, but **rect** is added to the region to update.

        **Note:** For non-exposed windows the update is deferred until the
        window becomes exposed again.
        """
        ...

    @typing.overload
    def update(self, region: "QRegion") -> None:
        """
        https://doc.qt.io/qt-6/qpaintdevicewindow.html#update-1

        **void QPaintDeviceWindow::update(const QRegion & region )**

        Marks the **region** of the window as dirty and schedules a repaint.

        **Note:** Subsequent calls to this function before the next paint event
        will get ignored, but **region** is added to the region to update.

        **Note:** For non-exposed windows the update is deferred until the
        window becomes exposed again.
        """
        ...

    @typing.overload
    def update(self) -> None:
        """
        https://doc.qt.io/qt-6/qpaintdevicewindow.html#update-2

        **[slot] void QPaintDeviceWindow::update()**

        Marks the entire window as dirty and schedules a repaint.

        **Note:** Subsequent calls to this function before the next paint event
        will get ignored.

        **Note:** For non-exposed windows the update is deferred until the
        window becomes exposed again.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStyleOptionProgressBar(QStyleOption):
    """
    https://doc.qt.io/qt-6/qstyleoptionprogressbar.html

    **Detailed Description**

    An instance of the QStyleOptionProgressBar class has type SO_ProgressBar and
    version 2.

    The type is used internally by **QStyleOption** , its subclasses, and
    **qstyleoption_cast** () to determine the type of style option. In general
    you do not need to worry about this unless you want to create your own
    **QStyleOption**  subclass and your own styles. The version is used by
    **QStyleOption**  subclasses to implement extensions without breaking
    compatibility. If you use **qstyleoption_cast** (), you normally do not need
    to check it.

    For performance reasons, there are few member functions and the access to
    the member variables is direct (i.e., using the `.` or `->` operator). This
    makes the structures straightforward to use and emphasizes that these are
    simply parameters used by the style functions.

    For an example demonstrating how style options can be used, see the
    **Styles**  example.

    **See also** **QStyleOption** .
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOptionProgressBar = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOptionProgressBar = ...

    bottomToTop: bool = ...
    invertedAppearance: bool = ...
    maximum: int = ...
    minimum: int = ...
    progress: int = ...
    text: str = ...
    textAlignment: QtCore = ...
    textVisible: bool = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionprogressbar.html#QStyleOptionProgress
        Bar

        **QStyleOptionProgressBar::QStyleOptionProgressBar()**

        Constructs a QStyleOptionProgressBar, initializing the members variables
        to their default values.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOptionProgressBar") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionprogressbar.html#QStyleOptionProgress
        Bar-1

        **QStyleOptionProgressBar::QStyleOptionProgressBar(const
        QStyleOptionProgressBar & other )**

        Constructs a copy of the **other** style option.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtSerialPort import *


class QSerialPortInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qserialportinfo.html

    **Detailed Description**

    Use the static functions to generate a list of QSerialPortInfo objects. Each
    QSerialPortInfo object in the list represents a single serial port and can
    be queried for the port name, system location, description, and
    manufacturer. The QSerialPortInfo class can also be used as an input
    parameter for the setPort() method of the **QSerialPort**  class.

    **See also** **QSerialPort** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#QSerialPortInfo

        **QSerialPortInfo::QSerialPortInfo()**

        Constructs an empty QSerialPortInfo object.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, port: QSerialPort) -> None:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#QSerialPortInfo-1

        **QSerialPortInfo::QSerialPortInfo(const QSerialPort & port )**

        Constructs a QSerialPortInfo object from serial **port**.
        """
        ...

    @typing.overload
    def __init__(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#QSerialPortInfo-2

        **QSerialPortInfo::QSerialPortInfo(const QString & name )**

        Constructs a QSerialPortInfo object from serial port **name**.

        This constructor finds the relevant serial port among the available ones
        according to the port name **name** , and constructs the serial port
        info instance for that port.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSerialPortInfo") -> None:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#QSerialPortInfo-3

        **QSerialPortInfo::QSerialPortInfo(const QSerialPortInfo & other )**

        Constructs a copy of **other**.
        """
        ...

    def serialNumber(self) -> str:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#serialNumber

        **[since 5.3] QString QSerialPortInfo::serialNumber() const**

        Returns the serial number string of the serial port, if available;
        otherwise returns an empty string.

        **Note:** The serial number may include letters.

        This function was introduced in Qt 5.3.

        **See also** **description** () and **manufacturer** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#isNull

        **bool QSerialPortInfo::isNull() const**

        Returns whether this **QSerialPortInfo**  object holds a serial port
        definition.
        """
        ...

    @staticmethod
    def availablePorts() -> typing.List["QSerialPortInfo"]:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#availablePorts

        **[static] QList<QSerialPortInfo> QSerialPortInfo::availablePorts()**

        Returns a list of available serial ports on the system.
        """
        ...

    @staticmethod
    def standardBaudRates() -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#standardBaudRates

        **[static] QList<qint32> QSerialPortInfo::standardBaudRates()**

        Returns a list of available standard baud rates supported by the target
        platform.
        """
        ...

    def hasProductIdentifier(self) -> bool:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#hasProductIdentifier

        **bool QSerialPortInfo::hasProductIdentifier() const**

        Returns `true` if there is a valid `16-bit` product number present;
        otherwise returns `false`.

        **See also** **productIdentifier** (), **vendorIdentifier** (), and
        **hasVendorIdentifier** ().
        """
        ...

    def hasVendorIdentifier(self) -> bool:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#hasVendorIdentifier

        **bool QSerialPortInfo::hasVendorIdentifier() const**

        Returns `true` if there is a valid `16-bit` vendor number present;
        otherwise returns `false`.

        **See also** **vendorIdentifier** (), **productIdentifier** (), and
        **hasProductIdentifier** ().
        """
        ...

    def productIdentifier(self) -> int:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#productIdentifier

        **quint16 QSerialPortInfo::productIdentifier() const**

        Returns the 16-bit product number for the serial port, if available;
        otherwise returns zero.

        **See also** **hasProductIdentifier** (), **vendorIdentifier** (), and
        **hasVendorIdentifier** ().
        """
        ...

    def vendorIdentifier(self) -> int:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#vendorIdentifier

        **quint16 QSerialPortInfo::vendorIdentifier() const**

        Returns the 16-bit vendor number for the serial port, if available;
        otherwise returns zero.

        **See also** **hasVendorIdentifier** (), **productIdentifier** (), and
        **hasProductIdentifier** ().
        """
        ...

    def manufacturer(self) -> str:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#manufacturer

        **QString QSerialPortInfo::manufacturer() const**

        Returns the manufacturer string of the serial port, if available;
        otherwise returns an empty string.

        **See also** **description** () and **serialNumber** ().
        """
        ...

    def description(self) -> str:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#description

        **QString QSerialPortInfo::description() const**

        Returns the description string of the serial port, if available;
        otherwise returns an empty string.

        **See also** **manufacturer** () and **serialNumber** ().
        """
        ...

    def systemLocation(self) -> str:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#systemLocation

        **QString QSerialPortInfo::systemLocation() const**

        Returns the system location of the serial port.

        **See also** **portName** ().
        """
        ...

    def portName(self) -> str:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#portName

        **QString QSerialPortInfo::portName() const**

        Returns the name of the serial port.

        **See also** **systemLocation** ().
        """
        ...

    def swap(self, other: "QSerialPortInfo") -> None:
        """
        https://doc.qt.io/qt-6/qserialportinfo.html#swap

        **void QSerialPortInfo::swap(QSerialPortInfo & other )**

        Swaps **QSerialPortInfo**  **other** with this **QSerialPortInfo** .
        This operation is very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QAnimationGroup(QAbstractAnimation):
    """
    https://doc.qt.io/qt-6/qanimationgroup.html

    **Detailed Description**

    An animation group is a container for animations (subclasses of
    **QAbstractAnimation** ). A group is usually responsible for managing the
    **state**  of its animations, i.e., it decides when to start, stop, resume,
    and pause them. Currently, Qt provides two such groups:
    **QParallelAnimationGroup**  and **QSequentialAnimationGroup** . Look up
    their class descriptions for details.

    Since QAnimationGroup inherits from **QAbstractAnimation** , you can combine
    groups, and easily construct complex animation graphs. You can query
    **QAbstractAnimation**  for the group it belongs to (using the **group** ()
    function).

    To start a top-level animation group, you simply use the **start** ()
    function from **QAbstractAnimation** . By a top-level animation group, we
    think of a group that itself is not contained within another group. Starting
    sub groups directly is not supported, and may lead to unexpected behavior.

    QAnimationGroup provides methods for adding and retrieving animations.
    Besides that, you can remove animations by calling **removeAnimation** (),
    and clear the animation group by calling **clear** (). You may keep track of
    changes in the group's animations by listening to **QEvent::ChildAdded**
    and **QEvent::ChildRemoved**  events.

    QAnimationGroup takes ownership of the animations it manages, and ensures
    that they are deleted when the animation group is deleted.

    **See also** **QAbstractAnimation** , **QVariantAnimation** , and **The
    Animation Framework** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qanimationgroup.html#QAnimationGroup

        **QAnimationGroup::QAnimationGroup(QObject * parent = nullptr)**

        Constructs a QAnimationGroup. **parent** is passed to **QObject** 's
        constructor.
        """
        ...

    def event(self, event: "QEvent") -> bool:
        """
        https://doc.qt.io/qt-6/qanimationgroup.html#event

        **[override virtual protected] bool QAnimationGroup::event(QEvent *
        event )**

        Reimplements: **QAbstractAnimation::event** (QEvent *event).
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qanimationgroup.html#clear

        **void QAnimationGroup::clear()**

        Removes and deletes all animations in this animation group, and resets
        the current time to 0.

        **See also** **addAnimation** () and **removeAnimation** ().
        """
        ...

    def takeAnimation(self, index: int) -> QAbstractAnimation:
        """
        https://doc.qt.io/qt-6/qanimationgroup.html#takeAnimation

        **QAbstractAnimation *QAnimationGroup::takeAnimation(int index )**

        Returns the animation at **index** and removes it from the animation
        group.

        **Note:** The ownership of the animation is transferred to the caller.

        **See also** **removeAnimation** (), **addAnimation** (),
        **insertAnimation** (), and **indexOfAnimation** ().
        """
        ...

    def removeAnimation(self, animation: QAbstractAnimation) -> None:
        """
        https://doc.qt.io/qt-6/qanimationgroup.html#removeAnimation

        **void QAnimationGroup::removeAnimation(QAbstractAnimation * animation
        )**

        Removes **animation** from this group. The ownership of **animation** is
        transferred to the caller.

        **See also** **takeAnimation** (), **insertAnimation** (), and
        **addAnimation** ().
        """
        ...

    def insertAnimation(self, index: int, animation: QAbstractAnimation) -> None:
        """
        https://doc.qt.io/qt-6/qanimationgroup.html#insertAnimation

        **void QAnimationGroup::insertAnimation(int index , QAbstractAnimation *
        animation )**

        Inserts **animation** into this animation group at **index**. If
        **index** is 0 the animation is inserted at the beginning. If **index**
        is **animationCount** (), the animation is inserted at the end.

        **Note:** The group takes ownership of the animation.

        **See also** **takeAnimation** (), **addAnimation** (),
        **indexOfAnimation** (), and **removeAnimation** ().
        """
        ...

    def addAnimation(self, animation: QAbstractAnimation) -> None:
        """
        https://doc.qt.io/qt-6/qanimationgroup.html#addAnimation

        **void QAnimationGroup::addAnimation(QAbstractAnimation * animation )**

        Adds **animation** to this group. This will call **insertAnimation**
        with index equals to **animationCount** ().

        **Note:** The group takes ownership of the animation.

        **See also** **removeAnimation** ().
        """
        ...

    def indexOfAnimation(self, animation: QAbstractAnimation) -> int:
        """
        https://doc.qt.io/qt-6/qanimationgroup.html#indexOfAnimation

        **int QAnimationGroup::indexOfAnimation(QAbstractAnimation * animation )
        const**

        Returns the index of **animation**. The returned index can be passed to
        the other functions that take an index as an argument.

        **See also** **insertAnimation** (), **animationAt** (), and
        **takeAnimation** ().
        """
        ...

    def animationCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qanimationgroup.html#animationCount

        **int QAnimationGroup::animationCount() const**

        Returns the number of animations managed by this group.

        **See also** **indexOfAnimation** (), **addAnimation** (), and
        **animationAt** ().
        """
        ...

    def animationAt(self, index: int) -> QAbstractAnimation:
        """
        https://doc.qt.io/qt-6/qanimationgroup.html#animationAt

        **QAbstractAnimation *QAnimationGroup::animationAt(int index ) const**

        Returns a pointer to the animation at **index** in this group. This
        function is useful when you need access to a particular animation.
        **index** is between 0 and **animationCount** () - 1.

        **See also** **animationCount** () and **indexOfAnimation** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QRadioButton(QAbstractButton):
    """
    https://doc.qt.io/qt-6/qradiobutton.html

    **Detailed Description**

    ![](images/windows-radiobutton.png)

    A QRadioButton is an option button that can be switched on (checked) or off
    (unchecked). Radio buttons typically present the user with a "one of many"
    choice. In a group of radio buttons, only one radio button at a time can be
    checked; if the user selects another button, the previously selected button
    is switched off.

    Radio buttons are autoExclusive by default. If auto-exclusive is enabled,
    radio buttons that belong to the same parent widget behave as if they were
    part of the same exclusive button group. If you need multiple exclusive
    button groups for radio buttons that belong to the same parent widget, put
    them into a **QButtonGroup** .

    Whenever a button is switched on or off, it emits the **toggled** () signal.
    Connect to this signal if you want to trigger an action each time the button
    changes state. Use **isChecked** () to see if a particular button is
    selected.

    Just like **QPushButton** , a radio button displays text, and optionally a
    small icon. The icon is set with **setIcon** (). The text can be set in the
    constructor or with **setText** (). A shortcut key can be specified by
    preceding the preferred character with an ampersand in the text. For
    example:

    **QRadioButton**  *button = new **QRadioButton** ("Search from the &cursor",
    this);

    In this example the shortcut is **Alt+c**. See the **QShortcut**
    documentation for details. To display an actual ampersand, use '&&'.

    Important inherited members: **text** (), **setText** (), **text** (),
    **setDown** (), **isDown** (), **autoRepeat** (), **group** (),
    **setAutoRepeat** (), **toggle** (), **pressed** (), **released** (),
    **clicked** (), and **toggled** ().

    **See also** **QPushButton** , **QToolButton** , **QCheckBox** , **GUI
    Design Handbook: Radio Button** , and **Group Box Example** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qradiobutton.html#QRadioButton

        **QRadioButton::QRadioButton(QWidget * parent = nullptr)**

        Constructs a radio button with the given **parent** , but with no text
        or pixmap.

        The **parent** argument is passed on to the **QAbstractButton**
        constructor.
        """
        ...

    @typing.overload
    def __init__(self, text: str, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qradiobutton.html#QRadioButton-1

        **QRadioButton::QRadioButton(const QString & text , QWidget * parent =
        nullptr)**

        Constructs a radio button with the given **parent** and **text** string.

        The **parent** argument is passed on to the **QAbstractButton**
        constructor.
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qradiobutton.html#mouseMoveEvent

        **[override virtual protected] void
        QRadioButton::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QAbstractButton::mouseMoveEvent** (QMouseEvent *e).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qradiobutton.html#paintEvent

        **[override virtual protected] void QRadioButton::paintEvent(QPaintEvent
        *)**

        Reimplements: **QAbstractButton::paintEvent** (QPaintEvent *e).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qradiobutton.html#event

        **[override virtual protected] bool QRadioButton::event(QEvent * e )**

        Reimplements: **QAbstractButton::event** (QEvent *e).
        """
        ...

    def hitButton(self, a0: QtCore.QPoint) -> bool:
        """
        https://doc.qt.io/qt-6/qradiobutton.html#hitButton

        **[override virtual protected] bool QRadioButton::hitButton(const QPoint
        & pos ) const**

        Reimplements: **QAbstractButton::hitButton(const QPoint &pos) const** .
        """
        ...

    def initStyleOption(self, button: "QStyleOptionButton") -> None:
        """
        https://doc.qt.io/qt-6/qradiobutton.html#initStyleOption

        **[virtual protected] void
        QRadioButton::initStyleOption(QStyleOptionButton * option ) const**

        Initialize **option** with the values from this **QRadioButton** . This
        method is useful for subclasses when they need a **QStyleOptionButton**
        , but don't want to fill in all the information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qradiobutton.html#minimumSizeHint

        **[override virtual] QSize QRadioButton::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qradiobutton.html#sizeHint

        **[override virtual] QSize QRadioButton::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...
